import {system, world} from '@minecraft/server';
function replaceEmojis(input) {
    const toHexSeq = emoji => [...emoji].map(c => c.codePointAt(0).toString(16).padStart(4, '0')).join('_');
    
    const emojiRegex = /[\p{Extended_Pictographic}\p{Ll}\p{Nd}](?:[\uFE0F\u20E3])?(?:\u200d[\p{Extended_Pictographic}\p{Ll}\p{Nd}](?:[\uFE0F\u20E3])?)*/gu;
    
    return input.replace(emojiRegex, emoji => {
        const seqs = [
            // Full sequence with all characters
            toHexSeq(emoji),
            // Sequence without variation selector and combining character
            toHexSeq(emoji.replace(/[\uFE0F\u20E3]/g, '')),
            // Sequence with just base characters
            toHexSeq(emoji.replace(/[\uFE0F\u20E3]/g, '').normalize('NFD').replace(/[\u0300-\u036F]/g, ''))
        ];
        
        for (const seq of seqs) {
            if (emojiLookUp[seq] !== undefined) {
                return String.fromCodePoint(emojiLookUp[seq]);
            }
        }
        
        return emoji;
    });
}
world.beforeEvents.chatSend.subscribe((event)=> {
    const player = event.sender;
    event.cancel = true;
    player.runCommandAsync(`say ${replaceEmojis(event.message)}`)
});
system.runInterval(
    () => {
        world.getAllPlayers().forEach(
            (player) => {
                if (player) {
                    let blockLookAt = player.getBlockFromViewDirection()?.block
                    if (blockLookAt) {
                        let previousTextSign = blockLookAt?.getComponent("minecraft:sign")?.getText();
                        if (previousTextSign) {
                            blockLookAt?.getComponent("minecraft:sign")?.setText(replaceEmojis(previousTextSign));
                        }
                    };
                    let heldItem = player.getComponent("minecraft:inventory")?.container?.getItem(player?.selectedSlotIndex);
                    if (heldItem) {
                        const inv = player.getComponent("minecraft:inventory")?.container;
                        const heldItem = inv.getItem(player?.selectedSlotIndex);
                        let previousName = heldItem.nameTag;
                        if (previousName && previousName.slice(0, 2) !== "§r") {
                            heldItem.nameTag = "§r" + replaceEmojis(previousName);
                            inv.setItem(player?.selectedSlotIndex, heldItem)
                        }
                    }
                };
            },
        );
    },
);

const emojiLookUp = {
    "0023": "0xE300",
    "0023_20e3": "0xE301",
    "002a": "0xE302",
    "002a_20e3": "0xE303",
    "0030": "0xE304",
    "0030_20e3": "0xE305",
    "0031": "0xE306",
    "0031_20e3": "0xE307",
    "0032": "0xE308",
    "0032_20e3": "0xE309",
    "0033": "0xE30A",
    "0033_20e3": "0xE30B",
    "0034": "0xE30C",
    "0034_20e3": "0xE30D",
    "0035": "0xE30E",
    "0035_20e3": "0xE30F",
    "0036": "0xE310",
    "0036_20e3": "0xE311",
    "0037": "0xE312",
    "0037_20e3": "0xE313",
    "0038": "0xE314",
    "0038_20e3": "0xE315",
    "0039": "0xE316",
    "0039_20e3": "0xE317",
    "00a9": "0xE318",
    "00ae": "0xE319",
    "1f004": "0xE31A",
    "1f0cf": "0xE31B",
    "1f170": "0xE31C",
    "1f171": "0xE31D",
    "1f17e": "0xE31E",
    "1f17f": "0xE31F",
    "1f18e": "0xE320",
    "1f191": "0xE321",
    "1f192": "0xE322",
    "1f193": "0xE323",
    "1f194": "0xE324",
    "1f195": "0xE325",
    "1f196": "0xE326",
    "1f197": "0xE327",
    "1f198": "0xE328",
    "1f199": "0xE329",
    "1f19a": "0xE32A",
    "1f1e6": "0xE32B",
    "1f1e7": "0xE32C",
    "1f1e8": "0xE32D",
    "1f1e9": "0xE32E",
    "1f1ea": "0xE32F",
    "1f1eb": "0xE330",
    "1f1ec": "0xE331",
    "1f1ed": "0xE332",
    "1f1ee": "0xE333",
    "1f1ef": "0xE334",
    "1f1f0": "0xE335",
    "1f1f1": "0xE336",
    "1f1f2": "0xE337",
    "1f1f3": "0xE338",
    "1f1f4": "0xE339",
    "1f1f5": "0xE33A",
    "1f1f6": "0xE33B",
    "1f1f7": "0xE33C",
    "1f1f8": "0xE33D",
    "1f1f9": "0xE33E",
    "1f1fa": "0xE33F",
    "1f1fb": "0xE340",
    "1f1fc": "0xE341",
    "1f1fd": "0xE342",
    "1f1fe": "0xE343",
    "1f1ff": "0xE344",
    "1f201": "0xE345",
    "1f202": "0xE346",
    "1f21a": "0xE347",
    "1f22f": "0xE348",
    "1f232": "0xE349",
    "1f233": "0xE34A",
    "1f234": "0xE34B",
    "1f235": "0xE34C",
    "1f236": "0xE34D",
    "1f237": "0xE34E",
    "1f238": "0xE34F",
    "1f239": "0xE350",
    "1f23a": "0xE351",
    "1f250": "0xE352",
    "1f251": "0xE353",
    "1f300": "0xE354",
    "1f301": "0xE355",
    "1f302": "0xE356",
    "1f303": "0xE357",
    "1f304": "0xE358",
    "1f305": "0xE359",
    "1f306": "0xE35A",
    "1f307": "0xE35B",
    "1f308": "0xE35C",
    "1f309": "0xE35D",
    "1f30a": "0xE35E",
    "1f30b": "0xE35F",
    "1f30c": "0xE360",
    "1f30d": "0xE361",
    "1f30e": "0xE362",
    "1f30f": "0xE363",
    "1f310": "0xE364",
    "1f311": "0xE365",
    "1f312": "0xE366",
    "1f313": "0xE367",
    "1f314": "0xE368",
    "1f315": "0xE369",
    "1f316": "0xE36A",
    "1f317": "0xE36B",
    "1f318": "0xE36C",
    "1f319": "0xE36D",
    "1f31a": "0xE36E",
    "1f31b": "0xE36F",
    "1f31c": "0xE370",
    "1f31d": "0xE371",
    "1f31e": "0xE372",
    "1f31f": "0xE373",
    "1f320": "0xE374",
    "1f321": "0xE375",
    "1f324": "0xE376",
    "1f325": "0xE377",
    "1f326": "0xE378",
    "1f327": "0xE379",
    "1f328": "0xE37A",
    "1f329": "0xE37B",
    "1f32a": "0xE37C",
    "1f32b": "0xE37D",
    "1f32c": "0xE37E",
    "1f32d": "0xE37F",
    "1f32e": "0xE380",
    "1f32f": "0xE381",
    "1f330": "0xE382",
    "1f331": "0xE383",
    "1f332": "0xE384",
    "1f333": "0xE385",
    "1f334": "0xE386",
    "1f335": "0xE387",
    "1f336": "0xE388",
    "1f337": "0xE389",
    "1f338": "0xE38A",
    "1f339": "0xE38B",
    "1f33a": "0xE38C",
    "1f33b": "0xE38D",
    "1f33c": "0xE38E",
    "1f33d": "0xE38F",
    "1f33e": "0xE390",
    "1f33f": "0xE391",
    "1f340": "0xE392",
    "1f341": "0xE393",
    "1f342": "0xE394",
    "1f343": "0xE395",
    "1f344": "0xE396",
    "1f344_200d_1f7eb": "0xE397",
    "1f345": "0xE398",
    "1f346": "0xE399",
    "1f347": "0xE39A",
    "1f348": "0xE39B",
    "1f349": "0xE39C",
    "1f34a": "0xE39D",
    "1f34b": "0xE39E",
    "1f34b_200d_1f7e9": "0xE39F",
    "1f34c": "0xE3A0",
    "1f34d": "0xE3A1",
    "1f34e": "0xE3A2",
    "1f34f": "0xE3A3",
    "1f350": "0xE3A4",
    "1f351": "0xE3A5",
    "1f352": "0xE3A6",
    "1f353": "0xE3A7",
    "1f354": "0xE3A8",
    "1f355": "0xE3A9",
    "1f356": "0xE3AA",
    "1f357": "0xE3AB",
    "1f358": "0xE3AC",
    "1f359": "0xE3AD",
    "1f35a": "0xE3AE",
    "1f35b": "0xE3AF",
    "1f35c": "0xE3B0",
    "1f35d": "0xE3B1",
    "1f35e": "0xE3B2",
    "1f35f": "0xE3B3",
    "1f360": "0xE3B4",
    "1f361": "0xE3B5",
    "1f362": "0xE3B6",
    "1f363": "0xE3B7",
    "1f364": "0xE3B8",
    "1f365": "0xE3B9",
    "1f366": "0xE3BA",
    "1f367": "0xE3BB",
    "1f368": "0xE3BC",
    "1f369": "0xE3BD",
    "1f36a": "0xE3BE",
    "1f36b": "0xE3BF",
    "1f36c": "0xE3C0",
    "1f36d": "0xE3C1",
    "1f36e": "0xE3C2",
    "1f36f": "0xE3C3",
    "1f370": "0xE3C4",
    "1f371": "0xE3C5",
    "1f372": "0xE3C6",
    "1f373": "0xE3C7",
    "1f374": "0xE3C8",
    "1f375": "0xE3C9",
    "1f376": "0xE3CA",
    "1f377": "0xE3CB",
    "1f378": "0xE3CC",
    "1f379": "0xE3CD",
    "1f37a": "0xE3CE",
    "1f37b": "0xE3CF",
    "1f37c": "0xE3D0",
    "1f37d": "0xE3D1",
    "1f37e": "0xE3D2",
    "1f37f": "0xE3D3",
    "1f380": "0xE3D4",
    "1f381": "0xE3D5",
    "1f382": "0xE3D6",
    "1f383": "0xE3D7",
    "1f384": "0xE3D8",
    "1f385": "0xE3D9",
    "1f385_1f3fb": "0xE3DA",
    "1f385_1f3fc": "0xE3DB",
    "1f385_1f3fd": "0xE3DC",
    "1f385_1f3fe": "0xE3DD",
    "1f385_1f3ff": "0xE3DE",
    "1f386": "0xE3DF",
    "1f387": "0xE3E0",
    "1f388": "0xE3E1",
    "1f389": "0xE3E2",
    "1f38a": "0xE3E3",
    "1f38b": "0xE3E4",
    "1f38c": "0xE3E5",
    "1f38d": "0xE3E6",
    "1f38e": "0xE3E7",
    "1f38f": "0xE3E8",
    "1f390": "0xE3E9",
    "1f391": "0xE3EA",
    "1f392": "0xE3EB",
    "1f393": "0xE3EC",
    "1f396": "0xE3ED",
    "1f397": "0xE3EE",
    "1f399": "0xE3EF",
    "1f39a": "0xE3F0",
    "1f39b": "0xE3F1",
    "1f39e": "0xE3F2",
    "1f39f": "0xE3F3",
    "1f3a0": "0xE3F4",
    "1f3a1": "0xE3F5",
    "1f3a2": "0xE3F6",
    "1f3a3": "0xE3F7",
    "1f3a4": "0xE3F8",
    "1f3a5": "0xE3F9",
    "1f3a6": "0xE3FA",
    "1f3a7": "0xE3FB",
    "1f3a8": "0xE3FC",
    "1f3a9": "0xE3FD",
    "1f3aa": "0xE3FE",
    "1f3ab": "0xE3FF",
    "1f3ac": "0xE400",
    "1f3ad": "0xE401",
    "1f3ae": "0xE402",
    "1f3af": "0xE403",
    "1f3b0": "0xE404",
    "1f3b1": "0xE405",
    "1f3b2": "0xE406",
    "1f3b3": "0xE407",
    "1f3b4": "0xE408",
    "1f3b5": "0xE409",
    "1f3b6": "0xE40A",
    "1f3b7": "0xE40B",
    "1f3b8": "0xE40C",
    "1f3b9": "0xE40D",
    "1f3ba": "0xE40E",
    "1f3bb": "0xE40F",
    "1f3bc": "0xE410",
    "1f3bd": "0xE411",
    "1f3be": "0xE412",
    "1f3bf": "0xE413",
    "1f3c0": "0xE414",
    "1f3c1": "0xE415",
    "1f3c2": "0xE416",
    "1f3c2_1f3fb": "0xE417",
    "1f3c2_1f3fc": "0xE418",
    "1f3c2_1f3fd": "0xE419",
    "1f3c2_1f3fe": "0xE41A",
    "1f3c2_1f3ff": "0xE41B",
    "1f3c3": "0xE41C",
    "1f3c3_1f3fb": "0xE41D",
    "1f3c3_1f3fb_200d_2640": "0xE41E",
    "1f3c3_1f3fb_200d_2640_200d_27a1": "0xE41F",
    "1f3c3_1f3fb_200d_2642": "0xE420",
    "1f3c3_1f3fb_200d_2642_200d_27a1": "0xE421",
    "1f3c3_1f3fb_200d_27a1": "0xE422",
    "1f3c3_1f3fc": "0xE423",
    "1f3c3_1f3fc_200d_2640": "0xE424",
    "1f3c3_1f3fc_200d_2640_200d_27a1": "0xE425",
    "1f3c3_1f3fc_200d_2642": "0xE426",
    "1f3c3_1f3fc_200d_2642_200d_27a1": "0xE427",
    "1f3c3_1f3fc_200d_27a1": "0xE428",
    "1f3c3_1f3fd": "0xE429",
    "1f3c3_1f3fd_200d_2640": "0xE42A",
    "1f3c3_1f3fd_200d_2640_200d_27a1": "0xE42B",
    "1f3c3_1f3fd_200d_2642": "0xE42C",
    "1f3c3_1f3fd_200d_2642_200d_27a1": "0xE42D",
    "1f3c3_1f3fd_200d_27a1": "0xE42E",
    "1f3c3_1f3fe": "0xE42F",
    "1f3c3_1f3fe_200d_2640": "0xE430",
    "1f3c3_1f3fe_200d_2640_200d_27a1": "0xE431",
    "1f3c3_1f3fe_200d_2642": "0xE432",
    "1f3c3_1f3fe_200d_2642_200d_27a1": "0xE433",
    "1f3c3_1f3fe_200d_27a1": "0xE434",
    "1f3c3_1f3ff": "0xE435",
    "1f3c3_1f3ff_200d_2640": "0xE436",
    "1f3c3_1f3ff_200d_2640_200d_27a1": "0xE437",
    "1f3c3_1f3ff_200d_2642": "0xE438",
    "1f3c3_1f3ff_200d_2642_200d_27a1": "0xE439",
    "1f3c3_1f3ff_200d_27a1": "0xE43A",
    "1f3c3_200d_2640": "0xE43B",
    "1f3c3_200d_2640_200d_27a1": "0xE43C",
    "1f3c3_200d_2642": "0xE43D",
    "1f3c3_200d_2642_200d_27a1": "0xE43E",
    "1f3c3_200d_27a1": "0xE43F",
    "1f3c4": "0xE440",
    "1f3c4_1f3fb": "0xE441",
    "1f3c4_1f3fb_200d_2640": "0xE442",
    "1f3c4_1f3fb_200d_2642": "0xE443",
    "1f3c4_1f3fc": "0xE444",
    "1f3c4_1f3fc_200d_2640": "0xE445",
    "1f3c4_1f3fc_200d_2642": "0xE446",
    "1f3c4_1f3fd": "0xE447",
    "1f3c4_1f3fd_200d_2640": "0xE448",
    "1f3c4_1f3fd_200d_2642": "0xE449",
    "1f3c4_1f3fe": "0xE44A",
    "1f3c4_1f3fe_200d_2640": "0xE44B",
    "1f3c4_1f3fe_200d_2642": "0xE44C",
    "1f3c4_1f3ff": "0xE44D",
    "1f3c4_1f3ff_200d_2640": "0xE44E",
    "1f3c4_1f3ff_200d_2642": "0xE44F",
    "1f3c4_200d_2640": "0xE450",
    "1f3c4_200d_2642": "0xE451",
    "1f3c5": "0xE452",
    "1f3c6": "0xE453",
    "1f3c7": "0xE454",
    "1f3c7_1f3fb": "0xE455",
    "1f3c7_1f3fc": "0xE456",
    "1f3c7_1f3fd": "0xE457",
    "1f3c7_1f3fe": "0xE458",
    "1f3c7_1f3ff": "0xE459",
    "1f3c8": "0xE45A",
    "1f3c9": "0xE45B",
    "1f3ca": "0xE45C",
    "1f3ca_1f3fb": "0xE45D",
    "1f3ca_1f3fb_200d_2640": "0xE45E",
    "1f3ca_1f3fb_200d_2642": "0xE45F",
    "1f3ca_1f3fc": "0xE460",
    "1f3ca_1f3fc_200d_2640": "0xE461",
    "1f3ca_1f3fc_200d_2642": "0xE462",
    "1f3ca_1f3fd": "0xE463",
    "1f3ca_1f3fd_200d_2640": "0xE464",
    "1f3ca_1f3fd_200d_2642": "0xE465",
    "1f3ca_1f3fe": "0xE466",
    "1f3ca_1f3fe_200d_2640": "0xE467",
    "1f3ca_1f3fe_200d_2642": "0xE468",
    "1f3ca_1f3ff": "0xE469",
    "1f3ca_1f3ff_200d_2640": "0xE46A",
    "1f3ca_1f3ff_200d_2642": "0xE46B",
    "1f3ca_200d_2640": "0xE46C",
    "1f3ca_200d_2642": "0xE46D",
    "1f3cb": "0xE46E",
    "1f3cb_1f3fb": "0xE46F",
    "1f3cb_1f3fb_200d_2640": "0xE470",
    "1f3cb_1f3fb_200d_2642": "0xE471",
    "1f3cb_1f3fc": "0xE472",
    "1f3cb_1f3fc_200d_2640": "0xE473",
    "1f3cb_1f3fc_200d_2642": "0xE474",
    "1f3cb_1f3fd": "0xE475",
    "1f3cb_1f3fd_200d_2640": "0xE476",
    "1f3cb_1f3fd_200d_2642": "0xE477",
    "1f3cb_1f3fe": "0xE478",
    "1f3cb_1f3fe_200d_2640": "0xE479",
    "1f3cb_1f3fe_200d_2642": "0xE47A",
    "1f3cb_1f3ff": "0xE47B",
    "1f3cb_1f3ff_200d_2640": "0xE47C",
    "1f3cb_1f3ff_200d_2642": "0xE47D",
    "1f3cb_200d_2640": "0xE47E",
    "1f3cb_200d_2642": "0xE47F",
    "1f3cc": "0xE480",
    "1f3cc_1f3fb": "0xE481",
    "1f3cc_1f3fb_200d_2640": "0xE482",
    "1f3cc_1f3fb_200d_2642": "0xE483",
    "1f3cc_1f3fc": "0xE484",
    "1f3cc_1f3fc_200d_2640": "0xE485",
    "1f3cc_1f3fc_200d_2642": "0xE486",
    "1f3cc_1f3fd": "0xE487",
    "1f3cc_1f3fd_200d_2640": "0xE488",
    "1f3cc_1f3fd_200d_2642": "0xE489",
    "1f3cc_1f3fe": "0xE48A",
    "1f3cc_1f3fe_200d_2640": "0xE48B",
    "1f3cc_1f3fe_200d_2642": "0xE48C",
    "1f3cc_1f3ff": "0xE48D",
    "1f3cc_1f3ff_200d_2640": "0xE48E",
    "1f3cc_1f3ff_200d_2642": "0xE48F",
    "1f3cc_200d_2640": "0xE490",
    "1f3cc_200d_2642": "0xE491",
    "1f3cd": "0xE492",
    "1f3ce": "0xE493",
    "1f3cf": "0xE494",
    "1f3d0": "0xE495",
    "1f3d1": "0xE496",
    "1f3d2": "0xE497",
    "1f3d3": "0xE498",
    "1f3d4": "0xE499",
    "1f3d5": "0xE49A",
    "1f3d6": "0xE49B",
    "1f3d7": "0xE49C",
    "1f3d8": "0xE49D",
    "1f3d9": "0xE49E",
    "1f3da": "0xE49F",
    "1f3db": "0xE4A0",
    "1f3dc": "0xE4A1",
    "1f3dd": "0xE4A2",
    "1f3de": "0xE4A3",
    "1f3df": "0xE4A4",
    "1f3e0": "0xE4A5",
    "1f3e1": "0xE4A6",
    "1f3e2": "0xE4A7",
    "1f3e3": "0xE4A8",
    "1f3e4": "0xE4A9",
    "1f3e5": "0xE4AA",
    "1f3e6": "0xE4AB",
    "1f3e7": "0xE4AC",
    "1f3e8": "0xE4AD",
    "1f3e9": "0xE4AE",
    "1f3ea": "0xE4AF",
    "1f3eb": "0xE4B0",
    "1f3ec": "0xE4B1",
    "1f3ed": "0xE4B2",
    "1f3ee": "0xE4B3",
    "1f3ef": "0xE4B4",
    "1f3f0": "0xE4B5",
    "1f3f3": "0xE4B6",
    "1f3f3_200d_1f308": "0xE4B7",
    "1f3f3_200d_26a7": "0xE4B8",
    "1f3f4": "0xE4B9",
    "1f3f4_200d_2620": "0xE4BA",
    "1f3f5": "0xE4BB",
    "1f3f7": "0xE4BC",
    "1f3f8": "0xE4BD",
    "1f3f9": "0xE4BE",
    "1f3fa": "0xE4BF",
    "1f3fb": "0xE4C0",
    "1f3fc": "0xE4C1",
    "1f3fd": "0xE4C2",
    "1f3fe": "0xE4C3",
    "1f3ff": "0xE4C4",
    "1f400": "0xE4C5",
    "1f401": "0xE4C6",
    "1f402": "0xE4C7",
    "1f403": "0xE4C8",
    "1f404": "0xE4C9",
    "1f405": "0xE4CA",
    "1f406": "0xE4CB",
    "1f407": "0xE4CC",
    "1f408": "0xE4CD",
    "1f408_200d_2b1b": "0xE4CE",
    "1f409": "0xE4CF",
    "1f40a": "0xE4D0",
    "1f40b": "0xE4D1",
    "1f40c": "0xE4D2",
    "1f40d": "0xE4D3",
    "1f40e": "0xE4D4",
    "1f40f": "0xE4D5",
    "1f410": "0xE4D6",
    "1f411": "0xE4D7",
    "1f412": "0xE4D8",
    "1f413": "0xE4D9",
    "1f414": "0xE4DA",
    "1f415": "0xE4DB",
    "1f415_200d_1f9ba": "0xE4DC",
    "1f416": "0xE4DD",
    "1f417": "0xE4DE",
    "1f418": "0xE4DF",
    "1f419": "0xE4E0",
    "1f41a": "0xE4E1",
    "1f41b": "0xE4E2",
    "1f41c": "0xE4E3",
    "1f41d": "0xE4E4",
    "1f41e": "0xE4E5",
    "1f41f": "0xE4E6",
    "1f420": "0xE4E7",
    "1f421": "0xE4E8",
    "1f422": "0xE4E9",
    "1f423": "0xE4EA",
    "1f424": "0xE4EB",
    "1f425": "0xE4EC",
    "1f426": "0xE4ED",
    "1f426_200d_1f525": "0xE4EE",
    "1f426_200d_2b1b": "0xE4EF",
    "1f427": "0xE4F0",
    "1f428": "0xE4F1",
    "1f429": "0xE4F2",
    "1f42a": "0xE4F3",
    "1f42b": "0xE4F4",
    "1f42c": "0xE4F5",
    "1f42d": "0xE4F6",
    "1f42e": "0xE4F7",
    "1f42f": "0xE4F8",
    "1f430": "0xE4F9",
    "1f431": "0xE4FA",
    "1f432": "0xE4FB",
    "1f433": "0xE4FC",
    "1f434": "0xE4FD",
    "1f435": "0xE4FE",
    "1f436": "0xE4FF",
    "1f437": "0xE500",
    "1f438": "0xE501",
    "1f439": "0xE502",
    "1f43a": "0xE503",
    "1f43b": "0xE504",
    "1f43b_200d_2744": "0xE505",
    "1f43c": "0xE506",
    "1f43d": "0xE507",
    "1f43e": "0xE508",
    "1f43f": "0xE509",
    "1f440": "0xE50A",
    "1f441": "0xE50B",
    "1f441_200d_1f5e8": "0xE50C",
    "1f442": "0xE50D",
    "1f442_1f3fb": "0xE50E",
    "1f442_1f3fc": "0xE50F",
    "1f442_1f3fd": "0xE510",
    "1f442_1f3fe": "0xE511",
    "1f442_1f3ff": "0xE512",
    "1f443": "0xE513",
    "1f443_1f3fb": "0xE514",
    "1f443_1f3fc": "0xE515",
    "1f443_1f3fd": "0xE516",
    "1f443_1f3fe": "0xE517",
    "1f443_1f3ff": "0xE518",
    "1f444": "0xE519",
    "1f445": "0xE51A",
    "1f446": "0xE51B",
    "1f446_1f3fb": "0xE51C",
    "1f446_1f3fc": "0xE51D",
    "1f446_1f3fd": "0xE51E",
    "1f446_1f3fe": "0xE51F",
    "1f446_1f3ff": "0xE520",
    "1f447": "0xE521",
    "1f447_1f3fb": "0xE522",
    "1f447_1f3fc": "0xE523",
    "1f447_1f3fd": "0xE524",
    "1f447_1f3fe": "0xE525",
    "1f447_1f3ff": "0xE526",
    "1f448": "0xE527",
    "1f448_1f3fb": "0xE528",
    "1f448_1f3fc": "0xE529",
    "1f448_1f3fd": "0xE52A",
    "1f448_1f3fe": "0xE52B",
    "1f448_1f3ff": "0xE52C",
    "1f449": "0xE52D",
    "1f449_1f3fb": "0xE52E",
    "1f449_1f3fc": "0xE52F",
    "1f449_1f3fd": "0xE530",
    "1f449_1f3fe": "0xE531",
    "1f449_1f3ff": "0xE532",
    "1f44a": "0xE533",
    "1f44a_1f3fb": "0xE534",
    "1f44a_1f3fc": "0xE535",
    "1f44a_1f3fd": "0xE536",
    "1f44a_1f3fe": "0xE537",
    "1f44a_1f3ff": "0xE538",
    "1f44b": "0xE539",
    "1f44b_1f3fb": "0xE53A",
    "1f44b_1f3fc": "0xE53B",
    "1f44b_1f3fd": "0xE53C",
    "1f44b_1f3fe": "0xE53D",
    "1f44b_1f3ff": "0xE53E",
    "1f44c": "0xE53F",
    "1f44c_1f3fb": "0xE540",
    "1f44c_1f3fc": "0xE541",
    "1f44c_1f3fd": "0xE542",
    "1f44c_1f3fe": "0xE543",
    "1f44c_1f3ff": "0xE544",
    "1f44d": "0xE545",
    "1f44d_1f3fb": "0xE546",
    "1f44d_1f3fc": "0xE547",
    "1f44d_1f3fd": "0xE548",
    "1f44d_1f3fe": "0xE549",
    "1f44d_1f3ff": "0xE54A",
    "1f44e": "0xE54B",
    "1f44e_1f3fb": "0xE54C",
    "1f44e_1f3fc": "0xE54D",
    "1f44e_1f3fd": "0xE54E",
    "1f44e_1f3fe": "0xE54F",
    "1f44e_1f3ff": "0xE550",
    "1f44f": "0xE551",
    "1f44f_1f3fb": "0xE552",
    "1f44f_1f3fc": "0xE553",
    "1f44f_1f3fd": "0xE554",
    "1f44f_1f3fe": "0xE555",
    "1f44f_1f3ff": "0xE556",
    "1f450": "0xE557",
    "1f450_1f3fb": "0xE558",
    "1f450_1f3fc": "0xE559",
    "1f450_1f3fd": "0xE55A",
    "1f450_1f3fe": "0xE55B",
    "1f450_1f3ff": "0xE55C",
    "1f451": "0xE55D",
    "1f452": "0xE55E",
    "1f453": "0xE55F",
    "1f454": "0xE560",
    "1f455": "0xE561",
    "1f456": "0xE562",
    "1f457": "0xE563",
    "1f458": "0xE564",
    "1f459": "0xE565",
    "1f45a": "0xE566",
    "1f45b": "0xE567",
    "1f45c": "0xE568",
    "1f45d": "0xE569",
    "1f45e": "0xE56A",
    "1f45f": "0xE56B",
    "1f460": "0xE56C",
    "1f461": "0xE56D",
    "1f462": "0xE56E",
    "1f463": "0xE56F",
    "1f464": "0xE570",
    "1f465": "0xE571",
    "1f466": "0xE572",
    "1f466_1f3fb": "0xE573",
    "1f466_1f3fc": "0xE574",
    "1f466_1f3fd": "0xE575",
    "1f466_1f3fe": "0xE576",
    "1f466_1f3ff": "0xE577",
    "1f467": "0xE578",
    "1f467_1f3fb": "0xE579",
    "1f467_1f3fc": "0xE57A",
    "1f467_1f3fd": "0xE57B",
    "1f467_1f3fe": "0xE57C",
    "1f467_1f3ff": "0xE57D",
    "1f468": "0xE57E",
    "1f468_1f3fb": "0xE57F",
    "1f468_1f3fb_200d_1f33e": "0xE580",
    "1f468_1f3fb_200d_1f373": "0xE581",
    "1f468_1f3fb_200d_1f37c": "0xE582",
    "1f468_1f3fb_200d_1f393": "0xE583",
    "1f468_1f3fb_200d_1f3a4": "0xE584",
    "1f468_1f3fb_200d_1f3a8": "0xE585",
    "1f468_1f3fb_200d_1f3eb": "0xE586",
    "1f468_1f3fb_200d_1f3ed": "0xE587",
    "1f468_1f3fb_200d_1f4bb": "0xE588",
    "1f468_1f3fb_200d_1f4bc": "0xE589",
    "1f468_1f3fb_200d_1f527": "0xE58A",
    "1f468_1f3fb_200d_1f52c": "0xE58B",
    "1f468_1f3fb_200d_1f680": "0xE58C",
    "1f468_1f3fb_200d_1f692": "0xE58D",
    "1f468_1f3fb_200d_1f91d_200d_1f468_1f3fc": "0xE58E",
    "1f468_1f3fb_200d_1f91d_200d_1f468_1f3fd": "0xE58F",
    "1f468_1f3fb_200d_1f91d_200d_1f468_1f3fe": "0xE590",
    "1f468_1f3fb_200d_1f91d_200d_1f468_1f3ff": "0xE591",
    "1f468_1f3fb_200d_1f9af": "0xE592",
    "1f468_1f3fb_200d_1f9af_200d_27a1": "0xE593",
    "1f468_1f3fb_200d_1f9b0": "0xE594",
    "1f468_1f3fb_200d_1f9b1": "0xE595",
    "1f468_1f3fb_200d_1f9b2": "0xE596",
    "1f468_1f3fb_200d_1f9b3": "0xE597",
    "1f468_1f3fb_200d_1f9bc": "0xE598",
    "1f468_1f3fb_200d_1f9bc_200d_27a1": "0xE599",
    "1f468_1f3fb_200d_1f9bd": "0xE59A",
    "1f468_1f3fb_200d_1f9bd_200d_27a1": "0xE59B",
    "1f468_1f3fb_200d_2695": "0xE59C",
    "1f468_1f3fb_200d_2696": "0xE59D",
    "1f468_1f3fb_200d_2708": "0xE59E",
    "1f468_1f3fb_200d_2764_200d_1f468_1f3fb": "0xE59F",
    "1f468_1f3fb_200d_2764_200d_1f468_1f3fc": "0xE5A0",
    "1f468_1f3fb_200d_2764_200d_1f468_1f3fd": "0xE5A1",
    "1f468_1f3fb_200d_2764_200d_1f468_1f3fe": "0xE5A2",
    "1f468_1f3fb_200d_2764_200d_1f468_1f3ff": "0xE5A3",
    "1f468_1f3fb_200d_2764_200d_1f48b_200d_1f468_1f3fb": "0xE5A4",
    "1f468_1f3fb_200d_2764_200d_1f48b_200d_1f468_1f3fc": "0xE5A5",
    "1f468_1f3fb_200d_2764_200d_1f48b_200d_1f468_1f3fd": "0xE5A6",
    "1f468_1f3fb_200d_2764_200d_1f48b_200d_1f468_1f3fe": "0xE5A7",
    "1f468_1f3fb_200d_2764_200d_1f48b_200d_1f468_1f3ff": "0xE5A8",
    "1f468_1f3fc": "0xE5A9",
    "1f468_1f3fc_200d_1f33e": "0xE5AA",
    "1f468_1f3fc_200d_1f373": "0xE5AB",
    "1f468_1f3fc_200d_1f37c": "0xE5AC",
    "1f468_1f3fc_200d_1f393": "0xE5AD",
    "1f468_1f3fc_200d_1f3a4": "0xE5AE",
    "1f468_1f3fc_200d_1f3a8": "0xE5AF",
    "1f468_1f3fc_200d_1f3eb": "0xE5B0",
    "1f468_1f3fc_200d_1f3ed": "0xE5B1",
    "1f468_1f3fc_200d_1f4bb": "0xE5B2",
    "1f468_1f3fc_200d_1f4bc": "0xE5B3",
    "1f468_1f3fc_200d_1f527": "0xE5B4",
    "1f468_1f3fc_200d_1f52c": "0xE5B5",
    "1f468_1f3fc_200d_1f680": "0xE5B6",
    "1f468_1f3fc_200d_1f692": "0xE5B7",
    "1f468_1f3fc_200d_1f91d_200d_1f468_1f3fb": "0xE5B8",
    "1f468_1f3fc_200d_1f91d_200d_1f468_1f3fd": "0xE5B9",
    "1f468_1f3fc_200d_1f91d_200d_1f468_1f3fe": "0xE5BA",
    "1f468_1f3fc_200d_1f91d_200d_1f468_1f3ff": "0xE5BB",
    "1f468_1f3fc_200d_1f9af": "0xE5BC",
    "1f468_1f3fc_200d_1f9af_200d_27a1": "0xE5BD",
    "1f468_1f3fc_200d_1f9b0": "0xE5BE",
    "1f468_1f3fc_200d_1f9b1": "0xE5BF",
    "1f468_1f3fc_200d_1f9b2": "0xE5C0",
    "1f468_1f3fc_200d_1f9b3": "0xE5C1",
    "1f468_1f3fc_200d_1f9bc": "0xE5C2",
    "1f468_1f3fc_200d_1f9bc_200d_27a1": "0xE5C3",
    "1f468_1f3fc_200d_1f9bd": "0xE5C4",
    "1f468_1f3fc_200d_1f9bd_200d_27a1": "0xE5C5",
    "1f468_1f3fc_200d_2695": "0xE5C6",
    "1f468_1f3fc_200d_2696": "0xE5C7",
    "1f468_1f3fc_200d_2708": "0xE5C8",
    "1f468_1f3fc_200d_2764_200d_1f468_1f3fb": "0xE5C9",
    "1f468_1f3fc_200d_2764_200d_1f468_1f3fc": "0xE5CA",
    "1f468_1f3fc_200d_2764_200d_1f468_1f3fd": "0xE5CB",
    "1f468_1f3fc_200d_2764_200d_1f468_1f3fe": "0xE5CC",
    "1f468_1f3fc_200d_2764_200d_1f468_1f3ff": "0xE5CD",
    "1f468_1f3fc_200d_2764_200d_1f48b_200d_1f468_1f3fb": "0xE5CE",
    "1f468_1f3fc_200d_2764_200d_1f48b_200d_1f468_1f3fc": "0xE5CF",
    "1f468_1f3fc_200d_2764_200d_1f48b_200d_1f468_1f3fd": "0xE5D0",
    "1f468_1f3fc_200d_2764_200d_1f48b_200d_1f468_1f3fe": "0xE5D1",
    "1f468_1f3fc_200d_2764_200d_1f48b_200d_1f468_1f3ff": "0xE5D2",
    "1f468_1f3fd": "0xE5D3",
    "1f468_1f3fd_200d_1f33e": "0xE5D4",
    "1f468_1f3fd_200d_1f373": "0xE5D5",
    "1f468_1f3fd_200d_1f37c": "0xE5D6",
    "1f468_1f3fd_200d_1f393": "0xE5D7",
    "1f468_1f3fd_200d_1f3a4": "0xE5D8",
    "1f468_1f3fd_200d_1f3a8": "0xE5D9",
    "1f468_1f3fd_200d_1f3eb": "0xE5DA",
    "1f468_1f3fd_200d_1f3ed": "0xE5DB",
    "1f468_1f3fd_200d_1f4bb": "0xE5DC",
    "1f468_1f3fd_200d_1f4bc": "0xE5DD",
    "1f468_1f3fd_200d_1f527": "0xE5DE",
    "1f468_1f3fd_200d_1f52c": "0xE5DF",
    "1f468_1f3fd_200d_1f680": "0xE5E0",
    "1f468_1f3fd_200d_1f692": "0xE5E1",
    "1f468_1f3fd_200d_1f91d_200d_1f468_1f3fb": "0xE5E2",
    "1f468_1f3fd_200d_1f91d_200d_1f468_1f3fc": "0xE5E3",
    "1f468_1f3fd_200d_1f91d_200d_1f468_1f3fe": "0xE5E4",
    "1f468_1f3fd_200d_1f91d_200d_1f468_1f3ff": "0xE5E5",
    "1f468_1f3fd_200d_1f9af": "0xE5E6",
    "1f468_1f3fd_200d_1f9af_200d_27a1": "0xE5E7",
    "1f468_1f3fd_200d_1f9b0": "0xE5E8",
    "1f468_1f3fd_200d_1f9b1": "0xE5E9",
    "1f468_1f3fd_200d_1f9b2": "0xE5EA",
    "1f468_1f3fd_200d_1f9b3": "0xE5EB",
    "1f468_1f3fd_200d_1f9bc": "0xE5EC",
    "1f468_1f3fd_200d_1f9bc_200d_27a1": "0xE5ED",
    "1f468_1f3fd_200d_1f9bd": "0xE5EE",
    "1f468_1f3fd_200d_1f9bd_200d_27a1": "0xE5EF",
    "1f468_1f3fd_200d_2695": "0xE5F0",
    "1f468_1f3fd_200d_2696": "0xE5F1",
    "1f468_1f3fd_200d_2708": "0xE5F2",
    "1f468_1f3fd_200d_2764_200d_1f468_1f3fb": "0xE5F3",
    "1f468_1f3fd_200d_2764_200d_1f468_1f3fc": "0xE5F4",
    "1f468_1f3fd_200d_2764_200d_1f468_1f3fd": "0xE5F5",
    "1f468_1f3fd_200d_2764_200d_1f468_1f3fe": "0xE5F6",
    "1f468_1f3fd_200d_2764_200d_1f468_1f3ff": "0xE5F7",
    "1f468_1f3fd_200d_2764_200d_1f48b_200d_1f468_1f3fb": "0xE5F8",
    "1f468_1f3fd_200d_2764_200d_1f48b_200d_1f468_1f3fc": "0xE5F9",
    "1f468_1f3fd_200d_2764_200d_1f48b_200d_1f468_1f3fd": "0xE5FA",
    "1f468_1f3fd_200d_2764_200d_1f48b_200d_1f468_1f3fe": "0xE5FB",
    "1f468_1f3fd_200d_2764_200d_1f48b_200d_1f468_1f3ff": "0xE5FC",
    "1f468_1f3fe": "0xE5FD",
    "1f468_1f3fe_200d_1f33e": "0xE5FE",
    "1f468_1f3fe_200d_1f373": "0xE5FF",
    "1f468_1f3fe_200d_1f37c": "0xE600",
    "1f468_1f3fe_200d_1f393": "0xE601",
    "1f468_1f3fe_200d_1f3a4": "0xE602",
    "1f468_1f3fe_200d_1f3a8": "0xE603",
    "1f468_1f3fe_200d_1f3eb": "0xE604",
    "1f468_1f3fe_200d_1f3ed": "0xE605",
    "1f468_1f3fe_200d_1f4bb": "0xE606",
    "1f468_1f3fe_200d_1f4bc": "0xE607",
    "1f468_1f3fe_200d_1f527": "0xE608",
    "1f468_1f3fe_200d_1f52c": "0xE609",
    "1f468_1f3fe_200d_1f680": "0xE60A",
    "1f468_1f3fe_200d_1f692": "0xE60B",
    "1f468_1f3fe_200d_1f91d_200d_1f468_1f3fb": "0xE60C",
    "1f468_1f3fe_200d_1f91d_200d_1f468_1f3fc": "0xE60D",
    "1f468_1f3fe_200d_1f91d_200d_1f468_1f3fd": "0xE60E",
    "1f468_1f3fe_200d_1f91d_200d_1f468_1f3ff": "0xE60F",
    "1f468_1f3fe_200d_1f9af": "0xE610",
    "1f468_1f3fe_200d_1f9af_200d_27a1": "0xE611",
    "1f468_1f3fe_200d_1f9b0": "0xE612",
    "1f468_1f3fe_200d_1f9b1": "0xE613",
    "1f468_1f3fe_200d_1f9b2": "0xE614",
    "1f468_1f3fe_200d_1f9b3": "0xE615",
    "1f468_1f3fe_200d_1f9bc": "0xE616",
    "1f468_1f3fe_200d_1f9bc_200d_27a1": "0xE617",
    "1f468_1f3fe_200d_1f9bd": "0xE618",
    "1f468_1f3fe_200d_1f9bd_200d_27a1": "0xE619",
    "1f468_1f3fe_200d_2695": "0xE61A",
    "1f468_1f3fe_200d_2696": "0xE61B",
    "1f468_1f3fe_200d_2708": "0xE61C",
    "1f468_1f3fe_200d_2764_200d_1f468_1f3fb": "0xE61D",
    "1f468_1f3fe_200d_2764_200d_1f468_1f3fc": "0xE61E",
    "1f468_1f3fe_200d_2764_200d_1f468_1f3fd": "0xE61F",
    "1f468_1f3fe_200d_2764_200d_1f468_1f3fe": "0xE620",
    "1f468_1f3fe_200d_2764_200d_1f468_1f3ff": "0xE621",
    "1f468_1f3fe_200d_2764_200d_1f48b_200d_1f468_1f3fb": "0xE622",
    "1f468_1f3fe_200d_2764_200d_1f48b_200d_1f468_1f3fc": "0xE623",
    "1f468_1f3fe_200d_2764_200d_1f48b_200d_1f468_1f3fd": "0xE624",
    "1f468_1f3fe_200d_2764_200d_1f48b_200d_1f468_1f3fe": "0xE625",
    "1f468_1f3fe_200d_2764_200d_1f48b_200d_1f468_1f3ff": "0xE626",
    "1f468_1f3ff": "0xE627",
    "1f468_1f3ff_200d_1f33e": "0xE628",
    "1f468_1f3ff_200d_1f373": "0xE629",
    "1f468_1f3ff_200d_1f37c": "0xE62A",
    "1f468_1f3ff_200d_1f393": "0xE62B",
    "1f468_1f3ff_200d_1f3a4": "0xE62C",
    "1f468_1f3ff_200d_1f3a8": "0xE62D",
    "1f468_1f3ff_200d_1f3eb": "0xE62E",
    "1f468_1f3ff_200d_1f3ed": "0xE62F",
    "1f468_1f3ff_200d_1f4bb": "0xE630",
    "1f468_1f3ff_200d_1f4bc": "0xE631",
    "1f468_1f3ff_200d_1f527": "0xE632",
    "1f468_1f3ff_200d_1f52c": "0xE633",
    "1f468_1f3ff_200d_1f680": "0xE634",
    "1f468_1f3ff_200d_1f692": "0xE635",
    "1f468_1f3ff_200d_1f91d_200d_1f468_1f3fb": "0xE636",
    "1f468_1f3ff_200d_1f91d_200d_1f468_1f3fc": "0xE637",
    "1f468_1f3ff_200d_1f91d_200d_1f468_1f3fd": "0xE638",
    "1f468_1f3ff_200d_1f91d_200d_1f468_1f3fe": "0xE639",
    "1f468_1f3ff_200d_1f9af": "0xE63A",
    "1f468_1f3ff_200d_1f9af_200d_27a1": "0xE63B",
    "1f468_1f3ff_200d_1f9b0": "0xE63C",
    "1f468_1f3ff_200d_1f9b1": "0xE63D",
    "1f468_1f3ff_200d_1f9b2": "0xE63E",
    "1f468_1f3ff_200d_1f9b3": "0xE63F",
    "1f468_1f3ff_200d_1f9bc": "0xE640",
    "1f468_1f3ff_200d_1f9bc_200d_27a1": "0xE641",
    "1f468_1f3ff_200d_1f9bd": "0xE642",
    "1f468_1f3ff_200d_1f9bd_200d_27a1": "0xE643",
    "1f468_1f3ff_200d_2695": "0xE644",
    "1f468_1f3ff_200d_2696": "0xE645",
    "1f468_1f3ff_200d_2708": "0xE646",
    "1f468_1f3ff_200d_2764_200d_1f468_1f3fb": "0xE647",
    "1f468_1f3ff_200d_2764_200d_1f468_1f3fc": "0xE648",
    "1f468_1f3ff_200d_2764_200d_1f468_1f3fd": "0xE649",
    "1f468_1f3ff_200d_2764_200d_1f468_1f3fe": "0xE64A",
    "1f468_1f3ff_200d_2764_200d_1f468_1f3ff": "0xE64B",
    "1f468_1f3ff_200d_2764_200d_1f48b_200d_1f468_1f3fb": "0xE64C",
    "1f468_1f3ff_200d_2764_200d_1f48b_200d_1f468_1f3fc": "0xE64D",
    "1f468_1f3ff_200d_2764_200d_1f48b_200d_1f468_1f3fd": "0xE64E",
    "1f468_1f3ff_200d_2764_200d_1f48b_200d_1f468_1f3fe": "0xE64F",
    "1f468_1f3ff_200d_2764_200d_1f48b_200d_1f468_1f3ff": "0xE650",
    "1f468_200d_1f33e": "0xE651",
    "1f468_200d_1f373": "0xE652",
    "1f468_200d_1f37c": "0xE653",
    "1f468_200d_1f393": "0xE654",
    "1f468_200d_1f3a4": "0xE655",
    "1f468_200d_1f3a8": "0xE656",
    "1f468_200d_1f3eb": "0xE657",
    "1f468_200d_1f3ed": "0xE658",
    "1f468_200d_1f466": "0xE659",
    "1f468_200d_1f466_200d_1f466": "0xE65A",
    "1f468_200d_1f467": "0xE65B",
    "1f468_200d_1f467_200d_1f466": "0xE65C",
    "1f468_200d_1f467_200d_1f467": "0xE65D",
    "1f468_200d_1f468_200d_1f466": "0xE65E",
    "1f468_200d_1f468_200d_1f466_200d_1f466": "0xE65F",
    "1f468_200d_1f468_200d_1f467": "0xE660",
    "1f468_200d_1f468_200d_1f467_200d_1f466": "0xE661",
    "1f468_200d_1f468_200d_1f467_200d_1f467": "0xE662",
    "1f468_200d_1f469_200d_1f466": "0xE663",
    "1f468_200d_1f469_200d_1f466_200d_1f466": "0xE664",
    "1f468_200d_1f469_200d_1f467": "0xE665",
    "1f468_200d_1f469_200d_1f467_200d_1f466": "0xE666",
    "1f468_200d_1f469_200d_1f467_200d_1f467": "0xE667",
    "1f468_200d_1f4bb": "0xE668",
    "1f468_200d_1f4bc": "0xE669",
    "1f468_200d_1f527": "0xE66A",
    "1f468_200d_1f52c": "0xE66B",
    "1f468_200d_1f680": "0xE66C",
    "1f468_200d_1f692": "0xE66D",
    "1f468_200d_1f9af": "0xE66E",
    "1f468_200d_1f9af_200d_27a1": "0xE66F",
    "1f468_200d_1f9b0": "0xE670",
    "1f468_200d_1f9b1": "0xE671",
    "1f468_200d_1f9b2": "0xE672",
    "1f468_200d_1f9b3": "0xE673",
    "1f468_200d_1f9bc": "0xE674",
    "1f468_200d_1f9bc_200d_27a1": "0xE675",
    "1f468_200d_1f9bd": "0xE676",
    "1f468_200d_1f9bd_200d_27a1": "0xE677",
    "1f468_200d_2695": "0xE678",
    "1f468_200d_2696": "0xE679",
    "1f468_200d_2708": "0xE67A",
    "1f468_200d_2764_200d_1f468": "0xE67B",
    "1f468_200d_2764_200d_1f48b_200d_1f468": "0xE67C",
    "1f469": "0xE67D",
    "1f469_1f3fb": "0xE67E",
    "1f469_1f3fb_200d_1f33e": "0xE67F",
    "1f469_1f3fb_200d_1f373": "0xE680",
    "1f469_1f3fb_200d_1f37c": "0xE681",
    "1f469_1f3fb_200d_1f393": "0xE682",
    "1f469_1f3fb_200d_1f3a4": "0xE683",
    "1f469_1f3fb_200d_1f3a8": "0xE684",
    "1f469_1f3fb_200d_1f3eb": "0xE685",
    "1f469_1f3fb_200d_1f3ed": "0xE686",
    "1f469_1f3fb_200d_1f4bb": "0xE687",
    "1f469_1f3fb_200d_1f4bc": "0xE688",
    "1f469_1f3fb_200d_1f527": "0xE689",
    "1f469_1f3fb_200d_1f52c": "0xE68A",
    "1f469_1f3fb_200d_1f680": "0xE68B",
    "1f469_1f3fb_200d_1f692": "0xE68C",
    "1f469_1f3fb_200d_1f91d_200d_1f468_1f3fc": "0xE68D",
    "1f469_1f3fb_200d_1f91d_200d_1f468_1f3fd": "0xE68E",
    "1f469_1f3fb_200d_1f91d_200d_1f468_1f3fe": "0xE68F",
    "1f469_1f3fb_200d_1f91d_200d_1f468_1f3ff": "0xE690",
    "1f469_1f3fb_200d_1f91d_200d_1f469_1f3fc": "0xE691",
    "1f469_1f3fb_200d_1f91d_200d_1f469_1f3fd": "0xE692",
    "1f469_1f3fb_200d_1f91d_200d_1f469_1f3fe": "0xE693",
    "1f469_1f3fb_200d_1f91d_200d_1f469_1f3ff": "0xE694",
    "1f469_1f3fb_200d_1f9af": "0xE695",
    "1f469_1f3fb_200d_1f9af_200d_27a1": "0xE696",
    "1f469_1f3fb_200d_1f9b0": "0xE697",
    "1f469_1f3fb_200d_1f9b1": "0xE698",
    "1f469_1f3fb_200d_1f9b2": "0xE699",
    "1f469_1f3fb_200d_1f9b3": "0xE69A",
    "1f469_1f3fb_200d_1f9bc": "0xE69B",
    "1f469_1f3fb_200d_1f9bc_200d_27a1": "0xE69C",
    "1f469_1f3fb_200d_1f9bd": "0xE69D",
    "1f469_1f3fb_200d_1f9bd_200d_27a1": "0xE69E",
    "1f469_1f3fb_200d_2695": "0xE69F",
    "1f469_1f3fb_200d_2696": "0xE6A0",
    "1f469_1f3fb_200d_2708": "0xE6A1",
    "1f469_1f3fb_200d_2764_200d_1f468_1f3fb": "0xE6A2",
    "1f469_1f3fb_200d_2764_200d_1f468_1f3fc": "0xE6A3",
    "1f469_1f3fb_200d_2764_200d_1f468_1f3fd": "0xE6A4",
    "1f469_1f3fb_200d_2764_200d_1f468_1f3fe": "0xE6A5",
    "1f469_1f3fb_200d_2764_200d_1f468_1f3ff": "0xE6A6",
    "1f469_1f3fb_200d_2764_200d_1f469_1f3fb": "0xE6A7",
    "1f469_1f3fb_200d_2764_200d_1f469_1f3fc": "0xE6A8",
    "1f469_1f3fb_200d_2764_200d_1f469_1f3fd": "0xE6A9",
    "1f469_1f3fb_200d_2764_200d_1f469_1f3fe": "0xE6AA",
    "1f469_1f3fb_200d_2764_200d_1f469_1f3ff": "0xE6AB",
    "1f469_1f3fb_200d_2764_200d_1f48b_200d_1f468_1f3fb": "0xE6AC",
    "1f469_1f3fb_200d_2764_200d_1f48b_200d_1f468_1f3fc": "0xE6AD",
    "1f469_1f3fb_200d_2764_200d_1f48b_200d_1f468_1f3fd": "0xE6AE",
    "1f469_1f3fb_200d_2764_200d_1f48b_200d_1f468_1f3fe": "0xE6AF",
    "1f469_1f3fb_200d_2764_200d_1f48b_200d_1f468_1f3ff": "0xE6B0",
    "1f469_1f3fb_200d_2764_200d_1f48b_200d_1f469_1f3fb": "0xE6B1",
    "1f469_1f3fb_200d_2764_200d_1f48b_200d_1f469_1f3fc": "0xE6B2",
    "1f469_1f3fb_200d_2764_200d_1f48b_200d_1f469_1f3fd": "0xE6B3",
    "1f469_1f3fb_200d_2764_200d_1f48b_200d_1f469_1f3fe": "0xE6B4",
    "1f469_1f3fb_200d_2764_200d_1f48b_200d_1f469_1f3ff": "0xE6B5",
    "1f469_1f3fc": "0xE6B6",
    "1f469_1f3fc_200d_1f33e": "0xE6B7",
    "1f469_1f3fc_200d_1f373": "0xE6B8",
    "1f469_1f3fc_200d_1f37c": "0xE6B9",
    "1f469_1f3fc_200d_1f393": "0xE6BA",
    "1f469_1f3fc_200d_1f3a4": "0xE6BB",
    "1f469_1f3fc_200d_1f3a8": "0xE6BC",
    "1f469_1f3fc_200d_1f3eb": "0xE6BD",
    "1f469_1f3fc_200d_1f3ed": "0xE6BE",
    "1f469_1f3fc_200d_1f4bb": "0xE6BF",
    "1f469_1f3fc_200d_1f4bc": "0xE6C0",
    "1f469_1f3fc_200d_1f527": "0xE6C1",
    "1f469_1f3fc_200d_1f52c": "0xE6C2",
    "1f469_1f3fc_200d_1f680": "0xE6C3",
    "1f469_1f3fc_200d_1f692": "0xE6C4",
    "1f469_1f3fc_200d_1f91d_200d_1f468_1f3fb": "0xE6C5",
    "1f469_1f3fc_200d_1f91d_200d_1f468_1f3fd": "0xE6C6",
    "1f469_1f3fc_200d_1f91d_200d_1f468_1f3fe": "0xE6C7",
    "1f469_1f3fc_200d_1f91d_200d_1f468_1f3ff": "0xE6C8",
    "1f469_1f3fc_200d_1f91d_200d_1f469_1f3fb": "0xE6C9",
    "1f469_1f3fc_200d_1f91d_200d_1f469_1f3fd": "0xE6CA",
    "1f469_1f3fc_200d_1f91d_200d_1f469_1f3fe": "0xE6CB",
    "1f469_1f3fc_200d_1f91d_200d_1f469_1f3ff": "0xE6CC",
    "1f469_1f3fc_200d_1f9af": "0xE6CD",
    "1f469_1f3fc_200d_1f9af_200d_27a1": "0xE6CE",
    "1f469_1f3fc_200d_1f9b0": "0xE6CF",
    "1f469_1f3fc_200d_1f9b1": "0xE6D0",
    "1f469_1f3fc_200d_1f9b2": "0xE6D1",
    "1f469_1f3fc_200d_1f9b3": "0xE6D2",
    "1f469_1f3fc_200d_1f9bc": "0xE6D3",
    "1f469_1f3fc_200d_1f9bc_200d_27a1": "0xE6D4",
    "1f469_1f3fc_200d_1f9bd": "0xE6D5",
    "1f469_1f3fc_200d_1f9bd_200d_27a1": "0xE6D6",
    "1f469_1f3fc_200d_2695": "0xE6D7",
    "1f469_1f3fc_200d_2696": "0xE6D8",
    "1f469_1f3fc_200d_2708": "0xE6D9",
    "1f469_1f3fc_200d_2764_200d_1f468_1f3fb": "0xE6DA",
    "1f469_1f3fc_200d_2764_200d_1f468_1f3fc": "0xE6DB",
    "1f469_1f3fc_200d_2764_200d_1f468_1f3fd": "0xE6DC",
    "1f469_1f3fc_200d_2764_200d_1f468_1f3fe": "0xE6DD",
    "1f469_1f3fc_200d_2764_200d_1f468_1f3ff": "0xE6DE",
    "1f469_1f3fc_200d_2764_200d_1f469_1f3fb": "0xE6DF",
    "1f469_1f3fc_200d_2764_200d_1f469_1f3fc": "0xE6E0",
    "1f469_1f3fc_200d_2764_200d_1f469_1f3fd": "0xE6E1",
    "1f469_1f3fc_200d_2764_200d_1f469_1f3fe": "0xE6E2",
    "1f469_1f3fc_200d_2764_200d_1f469_1f3ff": "0xE6E3",
    "1f469_1f3fc_200d_2764_200d_1f48b_200d_1f468_1f3fb": "0xE6E4",
    "1f469_1f3fc_200d_2764_200d_1f48b_200d_1f468_1f3fc": "0xE6E5",
    "1f469_1f3fc_200d_2764_200d_1f48b_200d_1f468_1f3fd": "0xE6E6",
    "1f469_1f3fc_200d_2764_200d_1f48b_200d_1f468_1f3fe": "0xE6E7",
    "1f469_1f3fc_200d_2764_200d_1f48b_200d_1f468_1f3ff": "0xE6E8",
    "1f469_1f3fc_200d_2764_200d_1f48b_200d_1f469_1f3fb": "0xE6E9",
    "1f469_1f3fc_200d_2764_200d_1f48b_200d_1f469_1f3fc": "0xE6EA",
    "1f469_1f3fc_200d_2764_200d_1f48b_200d_1f469_1f3fd": "0xE6EB",
    "1f469_1f3fc_200d_2764_200d_1f48b_200d_1f469_1f3fe": "0xE6EC",
    "1f469_1f3fc_200d_2764_200d_1f48b_200d_1f469_1f3ff": "0xE6ED",
    "1f469_1f3fd": "0xE6EE",
    "1f469_1f3fd_200d_1f33e": "0xE6EF",
    "1f469_1f3fd_200d_1f373": "0xE6F0",
    "1f469_1f3fd_200d_1f37c": "0xE6F1",
    "1f469_1f3fd_200d_1f393": "0xE6F2",
    "1f469_1f3fd_200d_1f3a4": "0xE6F3",
    "1f469_1f3fd_200d_1f3a8": "0xE6F4",
    "1f469_1f3fd_200d_1f3eb": "0xE6F5",
    "1f469_1f3fd_200d_1f3ed": "0xE6F6",
    "1f469_1f3fd_200d_1f4bb": "0xE6F7",
    "1f469_1f3fd_200d_1f4bc": "0xE6F8",
    "1f469_1f3fd_200d_1f527": "0xE6F9",
    "1f469_1f3fd_200d_1f52c": "0xE6FA",
    "1f469_1f3fd_200d_1f680": "0xE6FB",
    "1f469_1f3fd_200d_1f692": "0xE6FC",
    "1f469_1f3fd_200d_1f91d_200d_1f468_1f3fb": "0xE6FD",
    "1f469_1f3fd_200d_1f91d_200d_1f468_1f3fc": "0xE6FE",
    "1f469_1f3fd_200d_1f91d_200d_1f468_1f3fe": "0xE6FF",
    "1f469_1f3fd_200d_1f91d_200d_1f468_1f3ff": "0xE700",
    "1f469_1f3fd_200d_1f91d_200d_1f469_1f3fb": "0xE701",
    "1f469_1f3fd_200d_1f91d_200d_1f469_1f3fc": "0xE702",
    "1f469_1f3fd_200d_1f91d_200d_1f469_1f3fe": "0xE703",
    "1f469_1f3fd_200d_1f91d_200d_1f469_1f3ff": "0xE704",
    "1f469_1f3fd_200d_1f9af": "0xE705",
    "1f469_1f3fd_200d_1f9af_200d_27a1": "0xE706",
    "1f469_1f3fd_200d_1f9b0": "0xE707",
    "1f469_1f3fd_200d_1f9b1": "0xE708",
    "1f469_1f3fd_200d_1f9b2": "0xE709",
    "1f469_1f3fd_200d_1f9b3": "0xE70A",
    "1f469_1f3fd_200d_1f9bc": "0xE70B",
    "1f469_1f3fd_200d_1f9bc_200d_27a1": "0xE70C",
    "1f469_1f3fd_200d_1f9bd": "0xE70D",
    "1f469_1f3fd_200d_1f9bd_200d_27a1": "0xE70E",
    "1f469_1f3fd_200d_2695": "0xE70F",
    "1f469_1f3fd_200d_2696": "0xE710",
    "1f469_1f3fd_200d_2708": "0xE711",
    "1f469_1f3fd_200d_2764_200d_1f468_1f3fb": "0xE712",
    "1f469_1f3fd_200d_2764_200d_1f468_1f3fc": "0xE713",
    "1f469_1f3fd_200d_2764_200d_1f468_1f3fd": "0xE714",
    "1f469_1f3fd_200d_2764_200d_1f468_1f3fe": "0xE715",
    "1f469_1f3fd_200d_2764_200d_1f468_1f3ff": "0xE716",
    "1f469_1f3fd_200d_2764_200d_1f469_1f3fb": "0xE717",
    "1f469_1f3fd_200d_2764_200d_1f469_1f3fc": "0xE718",
    "1f469_1f3fd_200d_2764_200d_1f469_1f3fd": "0xE719",
    "1f469_1f3fd_200d_2764_200d_1f469_1f3fe": "0xE71A",
    "1f469_1f3fd_200d_2764_200d_1f469_1f3ff": "0xE71B",
    "1f469_1f3fd_200d_2764_200d_1f48b_200d_1f468_1f3fb": "0xE71C",
    "1f469_1f3fd_200d_2764_200d_1f48b_200d_1f468_1f3fc": "0xE71D",
    "1f469_1f3fd_200d_2764_200d_1f48b_200d_1f468_1f3fd": "0xE71E",
    "1f469_1f3fd_200d_2764_200d_1f48b_200d_1f468_1f3fe": "0xE71F",
    "1f469_1f3fd_200d_2764_200d_1f48b_200d_1f468_1f3ff": "0xE720",
    "1f469_1f3fd_200d_2764_200d_1f48b_200d_1f469_1f3fb": "0xE721",
    "1f469_1f3fd_200d_2764_200d_1f48b_200d_1f469_1f3fc": "0xE722",
    "1f469_1f3fd_200d_2764_200d_1f48b_200d_1f469_1f3fd": "0xE723",
    "1f469_1f3fd_200d_2764_200d_1f48b_200d_1f469_1f3fe": "0xE724",
    "1f469_1f3fd_200d_2764_200d_1f48b_200d_1f469_1f3ff": "0xE725",
    "1f469_1f3fe": "0xE726",
    "1f469_1f3fe_200d_1f33e": "0xE727",
    "1f469_1f3fe_200d_1f373": "0xE728",
    "1f469_1f3fe_200d_1f37c": "0xE729",
    "1f469_1f3fe_200d_1f393": "0xE72A",
    "1f469_1f3fe_200d_1f3a4": "0xE72B",
    "1f469_1f3fe_200d_1f3a8": "0xE72C",
    "1f469_1f3fe_200d_1f3eb": "0xE72D",
    "1f469_1f3fe_200d_1f3ed": "0xE72E",
    "1f469_1f3fe_200d_1f4bb": "0xE72F",
    "1f469_1f3fe_200d_1f4bc": "0xE730",
    "1f469_1f3fe_200d_1f527": "0xE731",
    "1f469_1f3fe_200d_1f52c": "0xE732",
    "1f469_1f3fe_200d_1f680": "0xE733",
    "1f469_1f3fe_200d_1f692": "0xE734",
    "1f469_1f3fe_200d_1f91d_200d_1f468_1f3fb": "0xE735",
    "1f469_1f3fe_200d_1f91d_200d_1f468_1f3fc": "0xE736",
    "1f469_1f3fe_200d_1f91d_200d_1f468_1f3fd": "0xE737",
    "1f469_1f3fe_200d_1f91d_200d_1f468_1f3ff": "0xE738",
    "1f469_1f3fe_200d_1f91d_200d_1f469_1f3fb": "0xE739",
    "1f469_1f3fe_200d_1f91d_200d_1f469_1f3fc": "0xE73A",
    "1f469_1f3fe_200d_1f91d_200d_1f469_1f3fd": "0xE73B",
    "1f469_1f3fe_200d_1f91d_200d_1f469_1f3ff": "0xE73C",
    "1f469_1f3fe_200d_1f9af": "0xE73D",
    "1f469_1f3fe_200d_1f9af_200d_27a1": "0xE73E",
    "1f469_1f3fe_200d_1f9b0": "0xE73F",
    "1f469_1f3fe_200d_1f9b1": "0xE740",
    "1f469_1f3fe_200d_1f9b2": "0xE741",
    "1f469_1f3fe_200d_1f9b3": "0xE742",
    "1f469_1f3fe_200d_1f9bc": "0xE743",
    "1f469_1f3fe_200d_1f9bc_200d_27a1": "0xE744",
    "1f469_1f3fe_200d_1f9bd": "0xE745",
    "1f469_1f3fe_200d_1f9bd_200d_27a1": "0xE746",
    "1f469_1f3fe_200d_2695": "0xE747",
    "1f469_1f3fe_200d_2696": "0xE748",
    "1f469_1f3fe_200d_2708": "0xE749",
    "1f469_1f3fe_200d_2764_200d_1f468_1f3fb": "0xE74A",
    "1f469_1f3fe_200d_2764_200d_1f468_1f3fc": "0xE74B",
    "1f469_1f3fe_200d_2764_200d_1f468_1f3fd": "0xE74C",
    "1f469_1f3fe_200d_2764_200d_1f468_1f3fe": "0xE74D",
    "1f469_1f3fe_200d_2764_200d_1f468_1f3ff": "0xE74E",
    "1f469_1f3fe_200d_2764_200d_1f469_1f3fb": "0xE74F",
    "1f469_1f3fe_200d_2764_200d_1f469_1f3fc": "0xE750",
    "1f469_1f3fe_200d_2764_200d_1f469_1f3fd": "0xE751",
    "1f469_1f3fe_200d_2764_200d_1f469_1f3fe": "0xE752",
    "1f469_1f3fe_200d_2764_200d_1f469_1f3ff": "0xE753",
    "1f469_1f3fe_200d_2764_200d_1f48b_200d_1f468_1f3fb": "0xE754",
    "1f469_1f3fe_200d_2764_200d_1f48b_200d_1f468_1f3fc": "0xE755",
    "1f469_1f3fe_200d_2764_200d_1f48b_200d_1f468_1f3fd": "0xE756",
    "1f469_1f3fe_200d_2764_200d_1f48b_200d_1f468_1f3fe": "0xE757",
    "1f469_1f3fe_200d_2764_200d_1f48b_200d_1f468_1f3ff": "0xE758",
    "1f469_1f3fe_200d_2764_200d_1f48b_200d_1f469_1f3fb": "0xE759",
    "1f469_1f3fe_200d_2764_200d_1f48b_200d_1f469_1f3fc": "0xE75A",
    "1f469_1f3fe_200d_2764_200d_1f48b_200d_1f469_1f3fd": "0xE75B",
    "1f469_1f3fe_200d_2764_200d_1f48b_200d_1f469_1f3fe": "0xE75C",
    "1f469_1f3fe_200d_2764_200d_1f48b_200d_1f469_1f3ff": "0xE75D",
    "1f469_1f3ff": "0xE75E",
    "1f469_1f3ff_200d_1f33e": "0xE75F",
    "1f469_1f3ff_200d_1f373": "0xE760",
    "1f469_1f3ff_200d_1f37c": "0xE761",
    "1f469_1f3ff_200d_1f393": "0xE762",
    "1f469_1f3ff_200d_1f3a4": "0xE763",
    "1f469_1f3ff_200d_1f3a8": "0xE764",
    "1f469_1f3ff_200d_1f3eb": "0xE765",
    "1f469_1f3ff_200d_1f3ed": "0xE766",
    "1f469_1f3ff_200d_1f4bb": "0xE767",
    "1f469_1f3ff_200d_1f4bc": "0xE768",
    "1f469_1f3ff_200d_1f527": "0xE769",
    "1f469_1f3ff_200d_1f52c": "0xE76A",
    "1f469_1f3ff_200d_1f680": "0xE76B",
    "1f469_1f3ff_200d_1f692": "0xE76C",
    "1f469_1f3ff_200d_1f91d_200d_1f468_1f3fb": "0xE76D",
    "1f469_1f3ff_200d_1f91d_200d_1f468_1f3fc": "0xE76E",
    "1f469_1f3ff_200d_1f91d_200d_1f468_1f3fd": "0xE76F",
    "1f469_1f3ff_200d_1f91d_200d_1f468_1f3fe": "0xE770",
    "1f469_1f3ff_200d_1f91d_200d_1f469_1f3fb": "0xE771",
    "1f469_1f3ff_200d_1f91d_200d_1f469_1f3fc": "0xE772",
    "1f469_1f3ff_200d_1f91d_200d_1f469_1f3fd": "0xE773",
    "1f469_1f3ff_200d_1f91d_200d_1f469_1f3fe": "0xE774",
    "1f469_1f3ff_200d_1f9af": "0xE775",
    "1f469_1f3ff_200d_1f9af_200d_27a1": "0xE776",
    "1f469_1f3ff_200d_1f9b0": "0xE777",
    "1f469_1f3ff_200d_1f9b1": "0xE778",
    "1f469_1f3ff_200d_1f9b2": "0xE779",
    "1f469_1f3ff_200d_1f9b3": "0xE77A",
    "1f469_1f3ff_200d_1f9bc": "0xE77B",
    "1f469_1f3ff_200d_1f9bc_200d_27a1": "0xE77C",
    "1f469_1f3ff_200d_1f9bd": "0xE77D",
    "1f469_1f3ff_200d_1f9bd_200d_27a1": "0xE77E",
    "1f469_1f3ff_200d_2695": "0xE77F",
    "1f469_1f3ff_200d_2696": "0xE780",
    "1f469_1f3ff_200d_2708": "0xE781",
    "1f469_1f3ff_200d_2764_200d_1f468_1f3fb": "0xE782",
    "1f469_1f3ff_200d_2764_200d_1f468_1f3fc": "0xE783",
    "1f469_1f3ff_200d_2764_200d_1f468_1f3fd": "0xE784",
    "1f469_1f3ff_200d_2764_200d_1f468_1f3fe": "0xE785",
    "1f469_1f3ff_200d_2764_200d_1f468_1f3ff": "0xE786",
    "1f469_1f3ff_200d_2764_200d_1f469_1f3fb": "0xE787",
    "1f469_1f3ff_200d_2764_200d_1f469_1f3fc": "0xE788",
    "1f469_1f3ff_200d_2764_200d_1f469_1f3fd": "0xE789",
    "1f469_1f3ff_200d_2764_200d_1f469_1f3fe": "0xE78A",
    "1f469_1f3ff_200d_2764_200d_1f469_1f3ff": "0xE78B",
    "1f469_1f3ff_200d_2764_200d_1f48b_200d_1f468_1f3fb": "0xE78C",
    "1f469_1f3ff_200d_2764_200d_1f48b_200d_1f468_1f3fc": "0xE78D",
    "1f469_1f3ff_200d_2764_200d_1f48b_200d_1f468_1f3fd": "0xE78E",
    "1f469_1f3ff_200d_2764_200d_1f48b_200d_1f468_1f3fe": "0xE78F",
    "1f469_1f3ff_200d_2764_200d_1f48b_200d_1f468_1f3ff": "0xE790",
    "1f469_1f3ff_200d_2764_200d_1f48b_200d_1f469_1f3fb": "0xE791",
    "1f469_1f3ff_200d_2764_200d_1f48b_200d_1f469_1f3fc": "0xE792",
    "1f469_1f3ff_200d_2764_200d_1f48b_200d_1f469_1f3fd": "0xE793",
    "1f469_1f3ff_200d_2764_200d_1f48b_200d_1f469_1f3fe": "0xE794",
    "1f469_1f3ff_200d_2764_200d_1f48b_200d_1f469_1f3ff": "0xE795",
    "1f469_200d_1f33e": "0xE796",
    "1f469_200d_1f373": "0xE797",
    "1f469_200d_1f37c": "0xE798",
    "1f469_200d_1f393": "0xE799",
    "1f469_200d_1f3a4": "0xE79A",
    "1f469_200d_1f3a8": "0xE79B",
    "1f469_200d_1f3eb": "0xE79C",
    "1f469_200d_1f3ed": "0xE79D",
    "1f469_200d_1f466": "0xE79E",
    "1f469_200d_1f466_200d_1f466": "0xE79F",
    "1f469_200d_1f467": "0xE7A0",
    "1f469_200d_1f467_200d_1f466": "0xE7A1",
    "1f469_200d_1f467_200d_1f467": "0xE7A2",
    "1f469_200d_1f469_200d_1f466": "0xE7A3",
    "1f469_200d_1f469_200d_1f466_200d_1f466": "0xE7A4",
    "1f469_200d_1f469_200d_1f467": "0xE7A5",
    "1f469_200d_1f469_200d_1f467_200d_1f466": "0xE7A6",
    "1f469_200d_1f469_200d_1f467_200d_1f467": "0xE7A7",
    "1f469_200d_1f4bb": "0xE7A8",
    "1f469_200d_1f4bc": "0xE7A9",
    "1f469_200d_1f527": "0xE7AA",
    "1f469_200d_1f52c": "0xE7AB",
    "1f469_200d_1f680": "0xE7AC",
    "1f469_200d_1f692": "0xE7AD",
    "1f469_200d_1f9af": "0xE7AE",
    "1f469_200d_1f9af_200d_27a1": "0xE7AF",
    "1f469_200d_1f9b0": "0xE7B0",
    "1f469_200d_1f9b1": "0xE7B1",
    "1f469_200d_1f9b2": "0xE7B2",
    "1f469_200d_1f9b3": "0xE7B3",
    "1f469_200d_1f9bc": "0xE7B4",
    "1f469_200d_1f9bc_200d_27a1": "0xE7B5",
    "1f469_200d_1f9bd": "0xE7B6",
    "1f469_200d_1f9bd_200d_27a1": "0xE7B7",
    "1f469_200d_2695": "0xE7B8",
    "1f469_200d_2696": "0xE7B9",
    "1f469_200d_2708": "0xE7BA",
    "1f469_200d_2764_200d_1f468": "0xE7BB",
    "1f469_200d_2764_200d_1f469": "0xE7BC",
    "1f469_200d_2764_200d_1f48b_200d_1f468": "0xE7BD",
    "1f469_200d_2764_200d_1f48b_200d_1f469": "0xE7BE",
    "1f46a": "0xE7BF",
    "1f46b": "0xE7C0",
    "1f46b_1f3fb": "0xE7C1",
    "1f46b_1f3fc": "0xE7C2",
    "1f46b_1f3fd": "0xE7C3",
    "1f46b_1f3fe": "0xE7C4",
    "1f46b_1f3ff": "0xE7C5",
    "1f46c": "0xE7C6",
    "1f46c_1f3fb": "0xE7C7",
    "1f46c_1f3fc": "0xE7C8",
    "1f46c_1f3fd": "0xE7C9",
    "1f46c_1f3fe": "0xE7CA",
    "1f46c_1f3ff": "0xE7CB",
    "1f46d": "0xE7CC",
    "1f46d_1f3fb": "0xE7CD",
    "1f46d_1f3fc": "0xE7CE",
    "1f46d_1f3fd": "0xE7CF",
    "1f46d_1f3fe": "0xE7D0",
    "1f46d_1f3ff": "0xE7D1",
    "1f46e": "0xE7D2",
    "1f46e_1f3fb": "0xE7D3",
    "1f46e_1f3fb_200d_2640": "0xE7D4",
    "1f46e_1f3fb_200d_2642": "0xE7D5",
    "1f46e_1f3fc": "0xE7D6",
    "1f46e_1f3fc_200d_2640": "0xE7D7",
    "1f46e_1f3fc_200d_2642": "0xE7D8",
    "1f46e_1f3fd": "0xE7D9",
    "1f46e_1f3fd_200d_2640": "0xE7DA",
    "1f46e_1f3fd_200d_2642": "0xE7DB",
    "1f46e_1f3fe": "0xE7DC",
    "1f46e_1f3fe_200d_2640": "0xE7DD",
    "1f46e_1f3fe_200d_2642": "0xE7DE",
    "1f46e_1f3ff": "0xE7DF",
    "1f46e_1f3ff_200d_2640": "0xE7E0",
    "1f46e_1f3ff_200d_2642": "0xE7E1",
    "1f46e_200d_2640": "0xE7E2",
    "1f46e_200d_2642": "0xE7E3",
    "1f46f": "0xE7E4",
    "1f46f_200d_2640": "0xE7E5",
    "1f46f_200d_2642": "0xE7E6",
    "1f470": "0xE7E7",
    "1f470_1f3fb": "0xE7E8",
    "1f470_1f3fb_200d_2640": "0xE7E9",
    "1f470_1f3fb_200d_2642": "0xE7EA",
    "1f470_1f3fc": "0xE7EB",
    "1f470_1f3fc_200d_2640": "0xE7EC",
    "1f470_1f3fc_200d_2642": "0xE7ED",
    "1f470_1f3fd": "0xE7EE",
    "1f470_1f3fd_200d_2640": "0xE7EF",
    "1f470_1f3fd_200d_2642": "0xE7F0",
    "1f470_1f3fe": "0xE7F1",
    "1f470_1f3fe_200d_2640": "0xE7F2",
    "1f470_1f3fe_200d_2642": "0xE7F3",
    "1f470_1f3ff": "0xE7F4",
    "1f470_1f3ff_200d_2640": "0xE7F5",
    "1f470_1f3ff_200d_2642": "0xE7F6",
    "1f470_200d_2640": "0xE7F7",
    "1f470_200d_2642": "0xE7F8",
    "1f471": "0xE7F9",
    "1f471_1f3fb": "0xE7FA",
    "1f471_1f3fb_200d_2640": "0xE7FB",
    "1f471_1f3fb_200d_2642": "0xE7FC",
    "1f471_1f3fc": "0xE7FD",
    "1f471_1f3fc_200d_2640": "0xE7FE",
    "1f471_1f3fc_200d_2642": "0xE7FF",
    "1f471_1f3fd": "0xE800",
    "1f471_1f3fd_200d_2640": "0xE801",
    "1f471_1f3fd_200d_2642": "0xE802",
    "1f471_1f3fe": "0xE803",
    "1f471_1f3fe_200d_2640": "0xE804",
    "1f471_1f3fe_200d_2642": "0xE805",
    "1f471_1f3ff": "0xE806",
    "1f471_1f3ff_200d_2640": "0xE807",
    "1f471_1f3ff_200d_2642": "0xE808",
    "1f471_200d_2640": "0xE809",
    "1f471_200d_2642": "0xE80A",
    "1f472": "0xE80B",
    "1f472_1f3fb": "0xE80C",
    "1f472_1f3fc": "0xE80D",
    "1f472_1f3fd": "0xE80E",
    "1f472_1f3fe": "0xE80F",
    "1f472_1f3ff": "0xE810",
    "1f473": "0xE811",
    "1f473_1f3fb": "0xE812",
    "1f473_1f3fb_200d_2640": "0xE813",
    "1f473_1f3fb_200d_2642": "0xE814",
    "1f473_1f3fc": "0xE815",
    "1f473_1f3fc_200d_2640": "0xE816",
    "1f473_1f3fc_200d_2642": "0xE817",
    "1f473_1f3fd": "0xE818",
    "1f473_1f3fd_200d_2640": "0xE819",
    "1f473_1f3fd_200d_2642": "0xE81A",
    "1f473_1f3fe": "0xE81B",
    "1f473_1f3fe_200d_2640": "0xE81C",
    "1f473_1f3fe_200d_2642": "0xE81D",
    "1f473_1f3ff": "0xE81E",
    "1f473_1f3ff_200d_2640": "0xE81F",
    "1f473_1f3ff_200d_2642": "0xE820",
    "1f473_200d_2640": "0xE821",
    "1f473_200d_2642": "0xE822",
    "1f474": "0xE823",
    "1f474_1f3fb": "0xE824",
    "1f474_1f3fc": "0xE825",
    "1f474_1f3fd": "0xE826",
    "1f474_1f3fe": "0xE827",
    "1f474_1f3ff": "0xE828",
    "1f475": "0xE829",
    "1f475_1f3fb": "0xE82A",
    "1f475_1f3fc": "0xE82B",
    "1f475_1f3fd": "0xE82C",
    "1f475_1f3fe": "0xE82D",
    "1f475_1f3ff": "0xE82E",
    "1f476": "0xE82F",
    "1f476_1f3fb": "0xE830",
    "1f476_1f3fc": "0xE831",
    "1f476_1f3fd": "0xE832",
    "1f476_1f3fe": "0xE833",
    "1f476_1f3ff": "0xE834",
    "1f477": "0xE835",
    "1f477_1f3fb": "0xE836",
    "1f477_1f3fb_200d_2640": "0xE837",
    "1f477_1f3fb_200d_2642": "0xE838",
    "1f477_1f3fc": "0xE839",
    "1f477_1f3fc_200d_2640": "0xE83A",
    "1f477_1f3fc_200d_2642": "0xE83B",
    "1f477_1f3fd": "0xE83C",
    "1f477_1f3fd_200d_2640": "0xE83D",
    "1f477_1f3fd_200d_2642": "0xE83E",
    "1f477_1f3fe": "0xE83F",
    "1f477_1f3fe_200d_2640": "0xE840",
    "1f477_1f3fe_200d_2642": "0xE841",
    "1f477_1f3ff": "0xE842",
    "1f477_1f3ff_200d_2640": "0xE843",
    "1f477_1f3ff_200d_2642": "0xE844",
    "1f477_200d_2640": "0xE845",
    "1f477_200d_2642": "0xE846",
    "1f478": "0xE847",
    "1f478_1f3fb": "0xE848",
    "1f478_1f3fc": "0xE849",
    "1f478_1f3fd": "0xE84A",
    "1f478_1f3fe": "0xE84B",
    "1f478_1f3ff": "0xE84C",
    "1f479": "0xE84D",
    "1f47a": "0xE84E",
    "1f47b": "0xE84F",
    "1f47c": "0xE850",
    "1f47c_1f3fb": "0xE851",
    "1f47c_1f3fc": "0xE852",
    "1f47c_1f3fd": "0xE853",
    "1f47c_1f3fe": "0xE854",
    "1f47c_1f3ff": "0xE855",
    "1f47d": "0xE856",
    "1f47e": "0xE857",
    "1f47f": "0xE858",
    "1f480": "0xE859",
    "1f481": "0xE85A",
    "1f481_1f3fb": "0xE85B",
    "1f481_1f3fb_200d_2640": "0xE85C",
    "1f481_1f3fb_200d_2642": "0xE85D",
    "1f481_1f3fc": "0xE85E",
    "1f481_1f3fc_200d_2640": "0xE85F",
    "1f481_1f3fc_200d_2642": "0xE860",
    "1f481_1f3fd": "0xE861",
    "1f481_1f3fd_200d_2640": "0xE862",
    "1f481_1f3fd_200d_2642": "0xE863",
    "1f481_1f3fe": "0xE864",
    "1f481_1f3fe_200d_2640": "0xE865",
    "1f481_1f3fe_200d_2642": "0xE866",
    "1f481_1f3ff": "0xE867",
    "1f481_1f3ff_200d_2640": "0xE868",
    "1f481_1f3ff_200d_2642": "0xE869",
    "1f481_200d_2640": "0xE86A",
    "1f481_200d_2642": "0xE86B",
    "1f482": "0xE86C",
    "1f482_1f3fb": "0xE86D",
    "1f482_1f3fb_200d_2640": "0xE86E",
    "1f482_1f3fb_200d_2642": "0xE86F",
    "1f482_1f3fc": "0xE870",
    "1f482_1f3fc_200d_2640": "0xE871",
    "1f482_1f3fc_200d_2642": "0xE872",
    "1f482_1f3fd": "0xE873",
    "1f482_1f3fd_200d_2640": "0xE874",
    "1f482_1f3fd_200d_2642": "0xE875",
    "1f482_1f3fe": "0xE876",
    "1f482_1f3fe_200d_2640": "0xE877",
    "1f482_1f3fe_200d_2642": "0xE878",
    "1f482_1f3ff": "0xE879",
    "1f482_1f3ff_200d_2640": "0xE87A",
    "1f482_1f3ff_200d_2642": "0xE87B",
    "1f482_200d_2640": "0xE87C",
    "1f482_200d_2642": "0xE87D",
    "1f483": "0xE87E",
    "1f483_1f3fb": "0xE87F",
    "1f483_1f3fc": "0xE880",
    "1f483_1f3fd": "0xE881",
    "1f483_1f3fe": "0xE882",
    "1f483_1f3ff": "0xE883",
    "1f484": "0xE884",
    "1f485": "0xE885",
    "1f485_1f3fb": "0xE886",
    "1f485_1f3fc": "0xE887",
    "1f485_1f3fd": "0xE888",
    "1f485_1f3fe": "0xE889",
    "1f485_1f3ff": "0xE88A",
    "1f486": "0xE88B",
    "1f486_1f3fb": "0xE88C",
    "1f486_1f3fb_200d_2640": "0xE88D",
    "1f486_1f3fb_200d_2642": "0xE88E",
    "1f486_1f3fc": "0xE88F",
    "1f486_1f3fc_200d_2640": "0xE890",
    "1f486_1f3fc_200d_2642": "0xE891",
    "1f486_1f3fd": "0xE892",
    "1f486_1f3fd_200d_2640": "0xE893",
    "1f486_1f3fd_200d_2642": "0xE894",
    "1f486_1f3fe": "0xE895",
    "1f486_1f3fe_200d_2640": "0xE896",
    "1f486_1f3fe_200d_2642": "0xE897",
    "1f486_1f3ff": "0xE898",
    "1f486_1f3ff_200d_2640": "0xE899",
    "1f486_1f3ff_200d_2642": "0xE89A",
    "1f486_200d_2640": "0xE89B",
    "1f486_200d_2642": "0xE89C",
    "1f487": "0xE89D",
    "1f487_1f3fb": "0xE89E",
    "1f487_1f3fb_200d_2640": "0xE89F",
    "1f487_1f3fb_200d_2642": "0xE8A0",
    "1f487_1f3fc": "0xE8A1",
    "1f487_1f3fc_200d_2640": "0xE8A2",
    "1f487_1f3fc_200d_2642": "0xE8A3",
    "1f487_1f3fd": "0xE8A4",
    "1f487_1f3fd_200d_2640": "0xE8A5",
    "1f487_1f3fd_200d_2642": "0xE8A6",
    "1f487_1f3fe": "0xE8A7",
    "1f487_1f3fe_200d_2640": "0xE8A8",
    "1f487_1f3fe_200d_2642": "0xE8A9",
    "1f487_1f3ff": "0xE8AA",
    "1f487_1f3ff_200d_2640": "0xE8AB",
    "1f487_1f3ff_200d_2642": "0xE8AC",
    "1f487_200d_2640": "0xE8AD",
    "1f487_200d_2642": "0xE8AE",
    "1f488": "0xE8AF",
    "1f489": "0xE8B0",
    "1f48a": "0xE8B1",
    "1f48b": "0xE8B2",
    "1f48c": "0xE8B3",
    "1f48d": "0xE8B4",
    "1f48e": "0xE8B5",
    "1f48f": "0xE8B6",
    "1f48f_1f3fb": "0xE8B7",
    "1f48f_1f3fc": "0xE8B8",
    "1f48f_1f3fd": "0xE8B9",
    "1f48f_1f3fe": "0xE8BA",
    "1f48f_1f3ff": "0xE8BB",
    "1f490": "0xE8BC",
    "1f491": "0xE8BD",
    "1f491_1f3fb": "0xE8BE",
    "1f491_1f3fc": "0xE8BF",
    "1f491_1f3fd": "0xE8C0",
    "1f491_1f3fe": "0xE8C1",
    "1f491_1f3ff": "0xE8C2",
    "1f492": "0xE8C3",
    "1f493": "0xE8C4",
    "1f494": "0xE8C5",
    "1f495": "0xE8C6",
    "1f496": "0xE8C7",
    "1f497": "0xE8C8",
    "1f498": "0xE8C9",
    "1f499": "0xE8CA",
    "1f49a": "0xE8CB",
    "1f49b": "0xE8CC",
    "1f49c": "0xE8CD",
    "1f49d": "0xE8CE",
    "1f49e": "0xE8CF",
    "1f49f": "0xE8D0",
    "1f4a0": "0xE8D1",
    "1f4a1": "0xE8D2",
    "1f4a2": "0xE8D3",
    "1f4a3": "0xE8D4",
    "1f4a4": "0xE8D5",
    "1f4a5": "0xE8D6",
    "1f4a6": "0xE8D7",
    "1f4a7": "0xE8D8",
    "1f4a8": "0xE8D9",
    "1f4a9": "0xE8DA",
    "1f4aa": "0xE8DB",
    "1f4aa_1f3fb": "0xE8DC",
    "1f4aa_1f3fc": "0xE8DD",
    "1f4aa_1f3fd": "0xE8DE",
    "1f4aa_1f3fe": "0xE8DF",
    "1f4aa_1f3ff": "0xE8E0",
    "1f4ab": "0xE8E1",
    "1f4ac": "0xE8E2",
    "1f4ad": "0xE8E3",
    "1f4ae": "0xE8E4",
    "1f4af": "0xE8E5",
    "1f4b0": "0xE8E6",
    "1f4b1": "0xE8E7",
    "1f4b2": "0xE8E8",
    "1f4b3": "0xE8E9",
    "1f4b4": "0xE8EA",
    "1f4b5": "0xE8EB",
    "1f4b6": "0xE8EC",
    "1f4b7": "0xE8ED",
    "1f4b8": "0xE8EE",
    "1f4b9": "0xE8EF",
    "1f4ba": "0xE8F0",
    "1f4bb": "0xE8F1",
    "1f4bc": "0xE8F2",
    "1f4bd": "0xE8F3",
    "1f4be": "0xE8F4",
    "1f4bf": "0xE8F5",
    "1f4c0": "0xE8F6",
    "1f4c1": "0xE8F7",
    "1f4c2": "0xE8F8",
    "1f4c3": "0xE8F9",
    "1f4c4": "0xE8FA",
    "1f4c5": "0xE8FB",
    "1f4c6": "0xE8FC",
    "1f4c7": "0xE8FD",
    "1f4c8": "0xE8FE",
    "1f4c9": "0xE8FF",
    "1f4ca": "0xE900",
    "1f4cb": "0xE901",
    "1f4cc": "0xE902",
    "1f4cd": "0xE903",
    "1f4ce": "0xE904",
    "1f4cf": "0xE905",
    "1f4d0": "0xE906",
    "1f4d1": "0xE907",
    "1f4d2": "0xE908",
    "1f4d3": "0xE909",
    "1f4d4": "0xE90A",
    "1f4d5": "0xE90B",
    "1f4d6": "0xE90C",
    "1f4d7": "0xE90D",
    "1f4d8": "0xE90E",
    "1f4d9": "0xE90F",
    "1f4da": "0xE910",
    "1f4db": "0xE911",
    "1f4dc": "0xE912",
    "1f4dd": "0xE913",
    "1f4de": "0xE914",
    "1f4df": "0xE915",
    "1f4e0": "0xE916",
    "1f4e1": "0xE917",
    "1f4e2": "0xE918",
    "1f4e3": "0xE919",
    "1f4e4": "0xE91A",
    "1f4e5": "0xE91B",
    "1f4e6": "0xE91C",
    "1f4e7": "0xE91D",
    "1f4e8": "0xE91E",
    "1f4e9": "0xE91F",
    "1f4ea": "0xE920",
    "1f4eb": "0xE921",
    "1f4ec": "0xE922",
    "1f4ed": "0xE923",
    "1f4ee": "0xE924",
    "1f4ef": "0xE925",
    "1f4f0": "0xE926",
    "1f4f1": "0xE927",
    "1f4f2": "0xE928",
    "1f4f3": "0xE929",
    "1f4f4": "0xE92A",
    "1f4f5": "0xE92B",
    "1f4f6": "0xE92C",
    "1f4f7": "0xE92D",
    "1f4f8": "0xE92E",
    "1f4f9": "0xE92F",
    "1f4fa": "0xE930",
    "1f4fb": "0xE931",
    "1f4fc": "0xE932",
    "1f4fd": "0xE933",
    "1f4ff": "0xE934",
    "1f500": "0xE935",
    "1f501": "0xE936",
    "1f502": "0xE937",
    "1f503": "0xE938",
    "1f504": "0xE939",
    "1f505": "0xE93A",
    "1f506": "0xE93B",
    "1f507": "0xE93C",
    "1f508": "0xE93D",
    "1f509": "0xE93E",
    "1f50a": "0xE93F",
    "1f50b": "0xE940",
    "1f50c": "0xE941",
    "1f50d": "0xE942",
    "1f50e": "0xE943",
    "1f50f": "0xE944",
    "1f510": "0xE945",
    "1f511": "0xE946",
    "1f512": "0xE947",
    "1f513": "0xE948",
    "1f514": "0xE949",
    "1f515": "0xE94A",
    "1f516": "0xE94B",
    "1f517": "0xE94C",
    "1f518": "0xE94D",
    "1f519": "0xE94E",
    "1f51a": "0xE94F",
    "1f51b": "0xE950",
    "1f51c": "0xE951",
    "1f51d": "0xE952",
    "1f51e": "0xE953",
    "1f51f": "0xE954",
    "1f520": "0xE955",
    "1f521": "0xE956",
    "1f522": "0xE957",
    "1f523": "0xE958",
    "1f524": "0xE959",
    "1f525": "0xE95A",
    "1f526": "0xE95B",
    "1f527": "0xE95C",
    "1f528": "0xE95D",
    "1f529": "0xE95E",
    "1f52a": "0xE95F",
    "1f52b": "0xE960",
    "1f52c": "0xE961",
    "1f52d": "0xE962",
    "1f52e": "0xE963",
    "1f52f": "0xE964",
    "1f530": "0xE965",
    "1f531": "0xE966",
    "1f532": "0xE967",
    "1f533": "0xE968",
    "1f534": "0xE969",
    "1f535": "0xE96A",
    "1f536": "0xE96B",
    "1f537": "0xE96C",
    "1f538": "0xE96D",
    "1f539": "0xE96E",
    "1f53a": "0xE96F",
    "1f53b": "0xE970",
    "1f53c": "0xE971",
    "1f53d": "0xE972",
    "1f549": "0xE973",
    "1f54a": "0xE974",
    "1f54b": "0xE975",
    "1f54c": "0xE976",
    "1f54d": "0xE977",
    "1f54e": "0xE978",
    "1f550": "0xE979",
    "1f551": "0xE97A",
    "1f552": "0xE97B",
    "1f553": "0xE97C",
    "1f554": "0xE97D",
    "1f555": "0xE97E",
    "1f556": "0xE97F",
    "1f557": "0xE980",
    "1f558": "0xE981",
    "1f559": "0xE982",
    "1f55a": "0xE983",
    "1f55b": "0xE984",
    "1f55c": "0xE985",
    "1f55d": "0xE986",
    "1f55e": "0xE987",
    "1f55f": "0xE988",
    "1f560": "0xE989",
    "1f561": "0xE98A",
    "1f562": "0xE98B",
    "1f563": "0xE98C",
    "1f564": "0xE98D",
    "1f565": "0xE98E",
    "1f566": "0xE98F",
    "1f567": "0xE990",
    "1f56f": "0xE991",
    "1f570": "0xE992",
    "1f573": "0xE993",
    "1f574": "0xE994",
    "1f574_1f3fb": "0xE995",
    "1f574_1f3fc": "0xE996",
    "1f574_1f3fd": "0xE997",
    "1f574_1f3fe": "0xE998",
    "1f574_1f3ff": "0xE999",
    "1f575": "0xE99A",
    "1f575_1f3fb": "0xE99B",
    "1f575_1f3fb_200d_2640": "0xE99C",
    "1f575_1f3fb_200d_2642": "0xE99D",
    "1f575_1f3fc": "0xE99E",
    "1f575_1f3fc_200d_2640": "0xE99F",
    "1f575_1f3fc_200d_2642": "0xE9A0",
    "1f575_1f3fd": "0xE9A1",
    "1f575_1f3fd_200d_2640": "0xE9A2",
    "1f575_1f3fd_200d_2642": "0xE9A3",
    "1f575_1f3fe": "0xE9A4",
    "1f575_1f3fe_200d_2640": "0xE9A5",
    "1f575_1f3fe_200d_2642": "0xE9A6",
    "1f575_1f3ff": "0xE9A7",
    "1f575_1f3ff_200d_2640": "0xE9A8",
    "1f575_1f3ff_200d_2642": "0xE9A9",
    "1f575_200d_2640": "0xE9AA",
    "1f575_200d_2642": "0xE9AB",
    "1f576": "0xE9AC",
    "1f577": "0xE9AD",
    "1f578": "0xE9AE",
    "1f579": "0xE9AF",
    "1f57a": "0xE9B0",
    "1f57a_1f3fb": "0xE9B1",
    "1f57a_1f3fc": "0xE9B2",
    "1f57a_1f3fd": "0xE9B3",
    "1f57a_1f3fe": "0xE9B4",
    "1f57a_1f3ff": "0xE9B5",
    "1f587": "0xE9B6",
    "1f58a": "0xE9B7",
    "1f58b": "0xE9B8",
    "1f58c": "0xE9B9",
    "1f58d": "0xE9BA",
    "1f590": "0xE9BB",
    "1f590_1f3fb": "0xE9BC",
    "1f590_1f3fc": "0xE9BD",
    "1f590_1f3fd": "0xE9BE",
    "1f590_1f3fe": "0xE9BF",
    "1f590_1f3ff": "0xE9C0",
    "1f595": "0xE9C1",
    "1f595_1f3fb": "0xE9C2",
    "1f595_1f3fc": "0xE9C3",
    "1f595_1f3fd": "0xE9C4",
    "1f595_1f3fe": "0xE9C5",
    "1f595_1f3ff": "0xE9C6",
    "1f596": "0xE9C7",
    "1f596_1f3fb": "0xE9C8",
    "1f596_1f3fc": "0xE9C9",
    "1f596_1f3fd": "0xE9CA",
    "1f596_1f3fe": "0xE9CB",
    "1f596_1f3ff": "0xE9CC",
    "1f5a4": "0xE9CD",
    "1f5a5": "0xE9CE",
    "1f5a8": "0xE9CF",
    "1f5b1": "0xE9D0",
    "1f5b2": "0xE9D1",
    "1f5bc": "0xE9D2",
    "1f5c2": "0xE9D3",
    "1f5c3": "0xE9D4",
    "1f5c4": "0xE9D5",
    "1f5d1": "0xE9D6",
    "1f5d2": "0xE9D7",
    "1f5d3": "0xE9D8",
    "1f5dc": "0xE9D9",
    "1f5dd": "0xE9DA",
    "1f5de": "0xE9DB",
    "1f5e1": "0xE9DC",
    "1f5e3": "0xE9DD",
    "1f5e8": "0xE9DE",
    "1f5ef": "0xE9DF",
    "1f5f3": "0xE9E0",
    "1f5fa": "0xE9E1",
    "1f5fb": "0xE9E2",
    "1f5fc": "0xE9E3",
    "1f5fd": "0xE9E4",
    "1f5fe": "0xE9E5",
    "1f5ff": "0xE9E6",
    "1f600": "0xE9E7",
    "1f601": "0xE9E8",
    "1f602": "0xE9E9",
    "1f603": "0xE9EA",
    "1f604": "0xE9EB",
    "1f605": "0xE9EC",
    "1f606": "0xE9ED",
    "1f607": "0xE9EE",
    "1f608": "0xE9EF",
    "1f609": "0xE9F0",
    "1f60a": "0xE9F1",
    "1f60b": "0xE9F2",
    "1f60c": "0xE9F3",
    "1f60d": "0xE9F4",
    "1f60e": "0xE9F5",
    "1f60f": "0xE9F6",
    "1f610": "0xE9F7",
    "1f611": "0xE9F8",
    "1f612": "0xE9F9",
    "1f613": "0xE9FA",
    "1f614": "0xE9FB",
    "1f615": "0xE9FC",
    "1f616": "0xE9FD",
    "1f617": "0xE9FE",
    "1f618": "0xE9FF",
    "1f619": "0xEA00",
    "1f61a": "0xEA01",
    "1f61b": "0xEA02",
    "1f61c": "0xEA03",
    "1f61d": "0xEA04",
    "1f61e": "0xEA05",
    "1f61f": "0xEA06",
    "1f620": "0xEA07",
    "1f621": "0xEA08",
    "1f622": "0xEA09",
    "1f623": "0xEA0A",
    "1f624": "0xEA0B",
    "1f625": "0xEA0C",
    "1f626": "0xEA0D",
    "1f627": "0xEA0E",
    "1f628": "0xEA0F",
    "1f629": "0xEA10",
    "1f62a": "0xEA11",
    "1f62b": "0xEA12",
    "1f62c": "0xEA13",
    "1f62d": "0xEA14",
    "1f62e": "0xEA15",
    "1f62e_200d_1f4a8": "0xEA16",
    "1f62f": "0xEA17",
    "1f630": "0xEA18",
    "1f631": "0xEA19",
    "1f632": "0xEA1A",
    "1f633": "0xEA1B",
    "1f634": "0xEA1C",
    "1f635": "0xEA1D",
    "1f635_200d_1f4ab": "0xEA1E",
    "1f636": "0xEA1F",
    "1f636_200d_1f32b": "0xEA20",
    "1f637": "0xEA21",
    "1f638": "0xEA22",
    "1f639": "0xEA23",
    "1f63a": "0xEA24",
    "1f63b": "0xEA25",
    "1f63c": "0xEA26",
    "1f63d": "0xEA27",
    "1f63e": "0xEA28",
    "1f63f": "0xEA29",
    "1f640": "0xEA2A",
    "1f641": "0xEA2B",
    "1f642": "0xEA2C",
    "1f642_200d_2194": "0xEA2D",
    "1f642_200d_2195": "0xEA2E",
    "1f643": "0xEA2F",
    "1f644": "0xEA30",
    "1f645": "0xEA31",
    "1f645_1f3fb": "0xEA32",
    "1f645_1f3fb_200d_2640": "0xEA33",
    "1f645_1f3fb_200d_2642": "0xEA34",
    "1f645_1f3fc": "0xEA35",
    "1f645_1f3fc_200d_2640": "0xEA36",
    "1f645_1f3fc_200d_2642": "0xEA37",
    "1f645_1f3fd": "0xEA38",
    "1f645_1f3fd_200d_2640": "0xEA39",
    "1f645_1f3fd_200d_2642": "0xEA3A",
    "1f645_1f3fe": "0xEA3B",
    "1f645_1f3fe_200d_2640": "0xEA3C",
    "1f645_1f3fe_200d_2642": "0xEA3D",
    "1f645_1f3ff": "0xEA3E",
    "1f645_1f3ff_200d_2640": "0xEA3F",
    "1f645_1f3ff_200d_2642": "0xEA40",
    "1f645_200d_2640": "0xEA41",
    "1f645_200d_2642": "0xEA42",
    "1f646": "0xEA43",
    "1f646_1f3fb": "0xEA44",
    "1f646_1f3fb_200d_2640": "0xEA45",
    "1f646_1f3fb_200d_2642": "0xEA46",
    "1f646_1f3fc": "0xEA47",
    "1f646_1f3fc_200d_2640": "0xEA48",
    "1f646_1f3fc_200d_2642": "0xEA49",
    "1f646_1f3fd": "0xEA4A",
    "1f646_1f3fd_200d_2640": "0xEA4B",
    "1f646_1f3fd_200d_2642": "0xEA4C",
    "1f646_1f3fe": "0xEA4D",
    "1f646_1f3fe_200d_2640": "0xEA4E",
    "1f646_1f3fe_200d_2642": "0xEA4F",
    "1f646_1f3ff": "0xEA50",
    "1f646_1f3ff_200d_2640": "0xEA51",
    "1f646_1f3ff_200d_2642": "0xEA52",
    "1f646_200d_2640": "0xEA53",
    "1f646_200d_2642": "0xEA54",
    "1f647": "0xEA55",
    "1f647_1f3fb": "0xEA56",
    "1f647_1f3fb_200d_2640": "0xEA57",
    "1f647_1f3fb_200d_2642": "0xEA58",
    "1f647_1f3fc": "0xEA59",
    "1f647_1f3fc_200d_2640": "0xEA5A",
    "1f647_1f3fc_200d_2642": "0xEA5B",
    "1f647_1f3fd": "0xEA5C",
    "1f647_1f3fd_200d_2640": "0xEA5D",
    "1f647_1f3fd_200d_2642": "0xEA5E",
    "1f647_1f3fe": "0xEA5F",
    "1f647_1f3fe_200d_2640": "0xEA60",
    "1f647_1f3fe_200d_2642": "0xEA61",
    "1f647_1f3ff": "0xEA62",
    "1f647_1f3ff_200d_2640": "0xEA63",
    "1f647_1f3ff_200d_2642": "0xEA64",
    "1f647_200d_2640": "0xEA65",
    "1f647_200d_2642": "0xEA66",
    "1f648": "0xEA67",
    "1f649": "0xEA68",
    "1f64a": "0xEA69",
    "1f64b": "0xEA6A",
    "1f64b_1f3fb": "0xEA6B",
    "1f64b_1f3fb_200d_2640": "0xEA6C",
    "1f64b_1f3fb_200d_2642": "0xEA6D",
    "1f64b_1f3fc": "0xEA6E",
    "1f64b_1f3fc_200d_2640": "0xEA6F",
    "1f64b_1f3fc_200d_2642": "0xEA70",
    "1f64b_1f3fd": "0xEA71",
    "1f64b_1f3fd_200d_2640": "0xEA72",
    "1f64b_1f3fd_200d_2642": "0xEA73",
    "1f64b_1f3fe": "0xEA74",
    "1f64b_1f3fe_200d_2640": "0xEA75",
    "1f64b_1f3fe_200d_2642": "0xEA76",
    "1f64b_1f3ff": "0xEA77",
    "1f64b_1f3ff_200d_2640": "0xEA78",
    "1f64b_1f3ff_200d_2642": "0xEA79",
    "1f64b_200d_2640": "0xEA7A",
    "1f64b_200d_2642": "0xEA7B",
    "1f64c": "0xEA7C",
    "1f64c_1f3fb": "0xEA7D",
    "1f64c_1f3fc": "0xEA7E",
    "1f64c_1f3fd": "0xEA7F",
    "1f64c_1f3fe": "0xEA80",
    "1f64c_1f3ff": "0xEA81",
    "1f64d": "0xEA82",
    "1f64d_1f3fb": "0xEA83",
    "1f64d_1f3fb_200d_2640": "0xEA84",
    "1f64d_1f3fb_200d_2642": "0xEA85",
    "1f64d_1f3fc": "0xEA86",
    "1f64d_1f3fc_200d_2640": "0xEA87",
    "1f64d_1f3fc_200d_2642": "0xEA88",
    "1f64d_1f3fd": "0xEA89",
    "1f64d_1f3fd_200d_2640": "0xEA8A",
    "1f64d_1f3fd_200d_2642": "0xEA8B",
    "1f64d_1f3fe": "0xEA8C",
    "1f64d_1f3fe_200d_2640": "0xEA8D",
    "1f64d_1f3fe_200d_2642": "0xEA8E",
    "1f64d_1f3ff": "0xEA8F",
    "1f64d_1f3ff_200d_2640": "0xEA90",
    "1f64d_1f3ff_200d_2642": "0xEA91",
    "1f64d_200d_2640": "0xEA92",
    "1f64d_200d_2642": "0xEA93",
    "1f64e": "0xEA94",
    "1f64e_1f3fb": "0xEA95",
    "1f64e_1f3fb_200d_2640": "0xEA96",
    "1f64e_1f3fb_200d_2642": "0xEA97",
    "1f64e_1f3fc": "0xEA98",
    "1f64e_1f3fc_200d_2640": "0xEA99",
    "1f64e_1f3fc_200d_2642": "0xEA9A",
    "1f64e_1f3fd": "0xEA9B",
    "1f64e_1f3fd_200d_2640": "0xEA9C",
    "1f64e_1f3fd_200d_2642": "0xEA9D",
    "1f64e_1f3fe": "0xEA9E",
    "1f64e_1f3fe_200d_2640": "0xEA9F",
    "1f64e_1f3fe_200d_2642": "0xEAA0",
    "1f64e_1f3ff": "0xEAA1",
    "1f64e_1f3ff_200d_2640": "0xEAA2",
    "1f64e_1f3ff_200d_2642": "0xEAA3",
    "1f64e_200d_2640": "0xEAA4",
    "1f64e_200d_2642": "0xEAA5",
    "1f64f": "0xEAA6",
    "1f64f_1f3fb": "0xEAA7",
    "1f64f_1f3fc": "0xEAA8",
    "1f64f_1f3fd": "0xEAA9",
    "1f64f_1f3fe": "0xEAAA",
    "1f64f_1f3ff": "0xEAAB",
    "1f680": "0xEAAC",
    "1f681": "0xEAAD",
    "1f682": "0xEAAE",
    "1f683": "0xEAAF",
    "1f684": "0xEAB0",
    "1f685": "0xEAB1",
    "1f686": "0xEAB2",
    "1f687": "0xEAB3",
    "1f688": "0xEAB4",
    "1f689": "0xEAB5",
    "1f68a": "0xEAB6",
    "1f68b": "0xEAB7",
    "1f68c": "0xEAB8",
    "1f68d": "0xEAB9",
    "1f68e": "0xEABA",
    "1f68f": "0xEABB",
    "1f690": "0xEABC",
    "1f691": "0xEABD",
    "1f692": "0xEABE",
    "1f693": "0xEABF",
    "1f694": "0xEAC0",
    "1f695": "0xEAC1",
    "1f696": "0xEAC2",
    "1f697": "0xEAC3",
    "1f698": "0xEAC4",
    "1f699": "0xEAC5",
    "1f69a": "0xEAC6",
    "1f69b": "0xEAC7",
    "1f69c": "0xEAC8",
    "1f69d": "0xEAC9",
    "1f69e": "0xEACA",
    "1f69f": "0xEACB",
    "1f6a0": "0xEACC",
    "1f6a1": "0xEACD",
    "1f6a2": "0xEACE",
    "1f6a3": "0xEACF",
    "1f6a3_1f3fb": "0xEAD0",
    "1f6a3_1f3fb_200d_2640": "0xEAD1",
    "1f6a3_1f3fb_200d_2642": "0xEAD2",
    "1f6a3_1f3fc": "0xEAD3",
    "1f6a3_1f3fc_200d_2640": "0xEAD4",
    "1f6a3_1f3fc_200d_2642": "0xEAD5",
    "1f6a3_1f3fd": "0xEAD6",
    "1f6a3_1f3fd_200d_2640": "0xEAD7",
    "1f6a3_1f3fd_200d_2642": "0xEAD8",
    "1f6a3_1f3fe": "0xEAD9",
    "1f6a3_1f3fe_200d_2640": "0xEADA",
    "1f6a3_1f3fe_200d_2642": "0xEADB",
    "1f6a3_1f3ff": "0xEADC",
    "1f6a3_1f3ff_200d_2640": "0xEADD",
    "1f6a3_1f3ff_200d_2642": "0xEADE",
    "1f6a3_200d_2640": "0xEADF",
    "1f6a3_200d_2642": "0xEAE0",
    "1f6a4": "0xEAE1",
    "1f6a5": "0xEAE2",
    "1f6a6": "0xEAE3",
    "1f6a7": "0xEAE4",
    "1f6a8": "0xEAE5",
    "1f6a9": "0xEAE6",
    "1f6aa": "0xEAE7",
    "1f6ab": "0xEAE8",
    "1f6ac": "0xEAE9",
    "1f6ad": "0xEAEA",
    "1f6ae": "0xEAEB",
    "1f6af": "0xEAEC",
    "1f6b0": "0xEAED",
    "1f6b1": "0xEAEE",
    "1f6b2": "0xEAEF",
    "1f6b3": "0xEAF0",
    "1f6b4": "0xEAF1",
    "1f6b4_1f3fb": "0xEAF2",
    "1f6b4_1f3fb_200d_2640": "0xEAF3",
    "1f6b4_1f3fb_200d_2642": "0xEAF4",
    "1f6b4_1f3fc": "0xEAF5",
    "1f6b4_1f3fc_200d_2640": "0xEAF6",
    "1f6b4_1f3fc_200d_2642": "0xEAF7",
    "1f6b4_1f3fd": "0xEAF8",
    "1f6b4_1f3fd_200d_2640": "0xEAF9",
    "1f6b4_1f3fd_200d_2642": "0xEAFA",
    "1f6b4_1f3fe": "0xEAFB",
    "1f6b4_1f3fe_200d_2640": "0xEAFC",
    "1f6b4_1f3fe_200d_2642": "0xEAFD",
    "1f6b4_1f3ff": "0xEAFE",
    "1f6b4_1f3ff_200d_2640": "0xEAFF",
    "1f6b4_1f3ff_200d_2642": "0xEB00",
    "1f6b4_200d_2640": "0xEB01",
    "1f6b4_200d_2642": "0xEB02",
    "1f6b5": "0xEB03",
    "1f6b5_1f3fb": "0xEB04",
    "1f6b5_1f3fb_200d_2640": "0xEB05",
    "1f6b5_1f3fb_200d_2642": "0xEB06",
    "1f6b5_1f3fc": "0xEB07",
    "1f6b5_1f3fc_200d_2640": "0xEB08",
    "1f6b5_1f3fc_200d_2642": "0xEB09",
    "1f6b5_1f3fd": "0xEB0A",
    "1f6b5_1f3fd_200d_2640": "0xEB0B",
    "1f6b5_1f3fd_200d_2642": "0xEB0C",
    "1f6b5_1f3fe": "0xEB0D",
    "1f6b5_1f3fe_200d_2640": "0xEB0E",
    "1f6b5_1f3fe_200d_2642": "0xEB0F",
    "1f6b5_1f3ff": "0xEB10",
    "1f6b5_1f3ff_200d_2640": "0xEB11",
    "1f6b5_1f3ff_200d_2642": "0xEB12",
    "1f6b5_200d_2640": "0xEB13",
    "1f6b5_200d_2642": "0xEB14",
    "1f6b6": "0xEB15",
    "1f6b6_1f3fb": "0xEB16",
    "1f6b6_1f3fb_200d_2640": "0xEB17",
    "1f6b6_1f3fb_200d_2640_200d_27a1": "0xEB18",
    "1f6b6_1f3fb_200d_2642": "0xEB19",
    "1f6b6_1f3fb_200d_2642_200d_27a1": "0xEB1A",
    "1f6b6_1f3fb_200d_27a1": "0xEB1B",
    "1f6b6_1f3fc": "0xEB1C",
    "1f6b6_1f3fc_200d_2640": "0xEB1D",
    "1f6b6_1f3fc_200d_2640_200d_27a1": "0xEB1E",
    "1f6b6_1f3fc_200d_2642": "0xEB1F",
    "1f6b6_1f3fc_200d_2642_200d_27a1": "0xEB20",
    "1f6b6_1f3fc_200d_27a1": "0xEB21",
    "1f6b6_1f3fd": "0xEB22",
    "1f6b6_1f3fd_200d_2640": "0xEB23",
    "1f6b6_1f3fd_200d_2640_200d_27a1": "0xEB24",
    "1f6b6_1f3fd_200d_2642": "0xEB25",
    "1f6b6_1f3fd_200d_2642_200d_27a1": "0xEB26",
    "1f6b6_1f3fd_200d_27a1": "0xEB27",
    "1f6b6_1f3fe": "0xEB28",
    "1f6b6_1f3fe_200d_2640": "0xEB29",
    "1f6b6_1f3fe_200d_2640_200d_27a1": "0xEB2A",
    "1f6b6_1f3fe_200d_2642": "0xEB2B",
    "1f6b6_1f3fe_200d_2642_200d_27a1": "0xEB2C",
    "1f6b6_1f3fe_200d_27a1": "0xEB2D",
    "1f6b6_1f3ff": "0xEB2E",
    "1f6b6_1f3ff_200d_2640": "0xEB2F",
    "1f6b6_1f3ff_200d_2640_200d_27a1": "0xEB30",
    "1f6b6_1f3ff_200d_2642": "0xEB31",
    "1f6b6_1f3ff_200d_2642_200d_27a1": "0xEB32",
    "1f6b6_1f3ff_200d_27a1": "0xEB33",
    "1f6b6_200d_2640": "0xEB34",
    "1f6b6_200d_2640_200d_27a1": "0xEB35",
    "1f6b6_200d_2642": "0xEB36",
    "1f6b6_200d_2642_200d_27a1": "0xEB37",
    "1f6b6_200d_27a1": "0xEB38",
    "1f6b7": "0xEB39",
    "1f6b8": "0xEB3A",
    "1f6b9": "0xEB3B",
    "1f6ba": "0xEB3C",
    "1f6bb": "0xEB3D",
    "1f6bc": "0xEB3E",
    "1f6bd": "0xEB3F",
    "1f6be": "0xEB40",
    "1f6bf": "0xEB41",
    "1f6c0": "0xEB42",
    "1f6c0_1f3fb": "0xEB43",
    "1f6c0_1f3fc": "0xEB44",
    "1f6c0_1f3fd": "0xEB45",
    "1f6c0_1f3fe": "0xEB46",
    "1f6c0_1f3ff": "0xEB47",
    "1f6c1": "0xEB48",
    "1f6c2": "0xEB49",
    "1f6c3": "0xEB4A",
    "1f6c4": "0xEB4B",
    "1f6c5": "0xEB4C",
    "1f6cb": "0xEB4D",
    "1f6cc": "0xEB4E",
    "1f6cc_1f3fb": "0xEB4F",
    "1f6cc_1f3fc": "0xEB50",
    "1f6cc_1f3fd": "0xEB51",
    "1f6cc_1f3fe": "0xEB52",
    "1f6cc_1f3ff": "0xEB53",
    "1f6cd": "0xEB54",
    "1f6ce": "0xEB55",
    "1f6cf": "0xEB56",
    "1f6d0": "0xEB57",
    "1f6d1": "0xEB58",
    "1f6d2": "0xEB59",
    "1f6d5": "0xEB5A",
    "1f6d6": "0xEB5B",
    "1f6d7": "0xEB5C",
    "1f6dc": "0xEB5D",
    "1f6dd": "0xEB5E",
    "1f6de": "0xEB5F",
    "1f6df": "0xEB60",
    "1f6e0": "0xEB61",
    "1f6e1": "0xEB62",
    "1f6e2": "0xEB63",
    "1f6e3": "0xEB64",
    "1f6e4": "0xEB65",
    "1f6e5": "0xEB66",
    "1f6e9": "0xEB67",
    "1f6eb": "0xEB68",
    "1f6ec": "0xEB69",
    "1f6f0": "0xEB6A",
    "1f6f3": "0xEB6B",
    "1f6f4": "0xEB6C",
    "1f6f5": "0xEB6D",
    "1f6f6": "0xEB6E",
    "1f6f7": "0xEB6F",
    "1f6f8": "0xEB70",
    "1f6f9": "0xEB71",
    "1f6fa": "0xEB72",
    "1f6fb": "0xEB73",
    "1f6fc": "0xEB74",
    "1f7e0": "0xEB75",
    "1f7e1": "0xEB76",
    "1f7e2": "0xEB77",
    "1f7e3": "0xEB78",
    "1f7e4": "0xEB79",
    "1f7e5": "0xEB7A",
    "1f7e6": "0xEB7B",
    "1f7e7": "0xEB7C",
    "1f7e8": "0xEB7D",
    "1f7e9": "0xEB7E",
    "1f7ea": "0xEB7F",
    "1f7eb": "0xEB80",
    "1f7f0": "0xEB81",
    "1f90c": "0xEB82",
    "1f90c_1f3fb": "0xEB83",
    "1f90c_1f3fc": "0xEB84",
    "1f90c_1f3fd": "0xEB85",
    "1f90c_1f3fe": "0xEB86",
    "1f90c_1f3ff": "0xEB87",
    "1f90d": "0xEB88",
    "1f90e": "0xEB89",
    "1f90f": "0xEB8A",
    "1f90f_1f3fb": "0xEB8B",
    "1f90f_1f3fc": "0xEB8C",
    "1f90f_1f3fd": "0xEB8D",
    "1f90f_1f3fe": "0xEB8E",
    "1f90f_1f3ff": "0xEB8F",
    "1f910": "0xEB90",
    "1f911": "0xEB91",
    "1f912": "0xEB92",
    "1f913": "0xEB93",
    "1f914": "0xEB94",
    "1f915": "0xEB95",
    "1f916": "0xEB96",
    "1f917": "0xEB97",
    "1f918": "0xEB98",
    "1f918_1f3fb": "0xEB99",
    "1f918_1f3fc": "0xEB9A",
    "1f918_1f3fd": "0xEB9B",
    "1f918_1f3fe": "0xEB9C",
    "1f918_1f3ff": "0xEB9D",
    "1f919": "0xEB9E",
    "1f919_1f3fb": "0xEB9F",
    "1f919_1f3fc": "0xEBA0",
    "1f919_1f3fd": "0xEBA1",
    "1f919_1f3fe": "0xEBA2",
    "1f919_1f3ff": "0xEBA3",
    "1f91a": "0xEBA4",
    "1f91a_1f3fb": "0xEBA5",
    "1f91a_1f3fc": "0xEBA6",
    "1f91a_1f3fd": "0xEBA7",
    "1f91a_1f3fe": "0xEBA8",
    "1f91a_1f3ff": "0xEBA9",
    "1f91b": "0xEBAA",
    "1f91b_1f3fb": "0xEBAB",
    "1f91b_1f3fc": "0xEBAC",
    "1f91b_1f3fd": "0xEBAD",
    "1f91b_1f3fe": "0xEBAE",
    "1f91b_1f3ff": "0xEBAF",
    "1f91c": "0xEBB0",
    "1f91c_1f3fb": "0xEBB1",
    "1f91c_1f3fc": "0xEBB2",
    "1f91c_1f3fd": "0xEBB3",
    "1f91c_1f3fe": "0xEBB4",
    "1f91c_1f3ff": "0xEBB5",
    "1f91d": "0xEBB6",
    "1f91d_1f3fb": "0xEBB7",
    "1f91d_1f3fc": "0xEBB8",
    "1f91d_1f3fd": "0xEBB9",
    "1f91d_1f3fe": "0xEBBA",
    "1f91d_1f3ff": "0xEBBB",
    "1f91e": "0xEBBC",
    "1f91e_1f3fb": "0xEBBD",
    "1f91e_1f3fc": "0xEBBE",
    "1f91e_1f3fd": "0xEBBF",
    "1f91e_1f3fe": "0xEBC0",
    "1f91e_1f3ff": "0xEBC1",
    "1f91f": "0xEBC2",
    "1f91f_1f3fb": "0xEBC3",
    "1f91f_1f3fc": "0xEBC4",
    "1f91f_1f3fd": "0xEBC5",
    "1f91f_1f3fe": "0xEBC6",
    "1f91f_1f3ff": "0xEBC7",
    "1f920": "0xEBC8",
    "1f921": "0xEBC9",
    "1f922": "0xEBCA",
    "1f923": "0xEBCB",
    "1f924": "0xEBCC",
    "1f925": "0xEBCD",
    "1f926": "0xEBCE",
    "1f926_1f3fb": "0xEBCF",
    "1f926_1f3fb_200d_2640": "0xEBD0",
    "1f926_1f3fb_200d_2642": "0xEBD1",
    "1f926_1f3fc": "0xEBD2",
    "1f926_1f3fc_200d_2640": "0xEBD3",
    "1f926_1f3fc_200d_2642": "0xEBD4",
    "1f926_1f3fd": "0xEBD5",
    "1f926_1f3fd_200d_2640": "0xEBD6",
    "1f926_1f3fd_200d_2642": "0xEBD7",
    "1f926_1f3fe": "0xEBD8",
    "1f926_1f3fe_200d_2640": "0xEBD9",
    "1f926_1f3fe_200d_2642": "0xEBDA",
    "1f926_1f3ff": "0xEBDB",
    "1f926_1f3ff_200d_2640": "0xEBDC",
    "1f926_1f3ff_200d_2642": "0xEBDD",
    "1f926_200d_2640": "0xEBDE",
    "1f926_200d_2642": "0xEBDF",
    "1f927": "0xEBE0",
    "1f928": "0xEBE1",
    "1f929": "0xEBE2",
    "1f92a": "0xEBE3",
    "1f92b": "0xEBE4",
    "1f92c": "0xEBE5",
    "1f92d": "0xEBE6",
    "1f92e": "0xEBE7",
    "1f92f": "0xEBE8",
    "1f930": "0xEBE9",
    "1f930_1f3fb": "0xEBEA",
    "1f930_1f3fc": "0xEBEB",
    "1f930_1f3fd": "0xEBEC",
    "1f930_1f3fe": "0xEBED",
    "1f930_1f3ff": "0xEBEE",
    "1f931": "0xEBEF",
    "1f931_1f3fb": "0xEBF0",
    "1f931_1f3fc": "0xEBF1",
    "1f931_1f3fd": "0xEBF2",
    "1f931_1f3fe": "0xEBF3",
    "1f931_1f3ff": "0xEBF4",
    "1f932": "0xEBF5",
    "1f932_1f3fb": "0xEBF6",
    "1f932_1f3fc": "0xEBF7",
    "1f932_1f3fd": "0xEBF8",
    "1f932_1f3fe": "0xEBF9",
    "1f932_1f3ff": "0xEBFA",
    "1f933": "0xEBFB",
    "1f933_1f3fb": "0xEBFC",
    "1f933_1f3fc": "0xEBFD",
    "1f933_1f3fd": "0xEBFE",
    "1f933_1f3fe": "0xEBFF",
    "1f933_1f3ff": "0xEC00",
    "1f934": "0xEC01",
    "1f934_1f3fb": "0xEC02",
    "1f934_1f3fc": "0xEC03",
    "1f934_1f3fd": "0xEC04",
    "1f934_1f3fe": "0xEC05",
    "1f934_1f3ff": "0xEC06",
    "1f935": "0xEC07",
    "1f935_1f3fb": "0xEC08",
    "1f935_1f3fb_200d_2640": "0xEC09",
    "1f935_1f3fb_200d_2642": "0xEC0A",
    "1f935_1f3fc": "0xEC0B",
    "1f935_1f3fc_200d_2640": "0xEC0C",
    "1f935_1f3fc_200d_2642": "0xEC0D",
    "1f935_1f3fd": "0xEC0E",
    "1f935_1f3fd_200d_2640": "0xEC0F",
    "1f935_1f3fd_200d_2642": "0xEC10",
    "1f935_1f3fe": "0xEC11",
    "1f935_1f3fe_200d_2640": "0xEC12",
    "1f935_1f3fe_200d_2642": "0xEC13",
    "1f935_1f3ff": "0xEC14",
    "1f935_1f3ff_200d_2640": "0xEC15",
    "1f935_1f3ff_200d_2642": "0xEC16",
    "1f935_200d_2640": "0xEC17",
    "1f935_200d_2642": "0xEC18",
    "1f936": "0xEC19",
    "1f936_1f3fb": "0xEC1A",
    "1f936_1f3fc": "0xEC1B",
    "1f936_1f3fd": "0xEC1C",
    "1f936_1f3fe": "0xEC1D",
    "1f936_1f3ff": "0xEC1E",
    "1f937": "0xEC1F",
    "1f937_1f3fb": "0xEC20",
    "1f937_1f3fb_200d_2640": "0xEC21",
    "1f937_1f3fb_200d_2642": "0xEC22",
    "1f937_1f3fc": "0xEC23",
    "1f937_1f3fc_200d_2640": "0xEC24",
    "1f937_1f3fc_200d_2642": "0xEC25",
    "1f937_1f3fd": "0xEC26",
    "1f937_1f3fd_200d_2640": "0xEC27",
    "1f937_1f3fd_200d_2642": "0xEC28",
    "1f937_1f3fe": "0xEC29",
    "1f937_1f3fe_200d_2640": "0xEC2A",
    "1f937_1f3fe_200d_2642": "0xEC2B",
    "1f937_1f3ff": "0xEC2C",
    "1f937_1f3ff_200d_2640": "0xEC2D",
    "1f937_1f3ff_200d_2642": "0xEC2E",
    "1f937_200d_2640": "0xEC2F",
    "1f937_200d_2642": "0xEC30",
    "1f938": "0xEC31",
    "1f938_1f3fb": "0xEC32",
    "1f938_1f3fb_200d_2640": "0xEC33",
    "1f938_1f3fb_200d_2642": "0xEC34",
    "1f938_1f3fc": "0xEC35",
    "1f938_1f3fc_200d_2640": "0xEC36",
    "1f938_1f3fc_200d_2642": "0xEC37",
    "1f938_1f3fd": "0xEC38",
    "1f938_1f3fd_200d_2640": "0xEC39",
    "1f938_1f3fd_200d_2642": "0xEC3A",
    "1f938_1f3fe": "0xEC3B",
    "1f938_1f3fe_200d_2640": "0xEC3C",
    "1f938_1f3fe_200d_2642": "0xEC3D",
    "1f938_1f3ff": "0xEC3E",
    "1f938_1f3ff_200d_2640": "0xEC3F",
    "1f938_1f3ff_200d_2642": "0xEC40",
    "1f938_200d_2640": "0xEC41",
    "1f938_200d_2642": "0xEC42",
    "1f939": "0xEC43",
    "1f939_1f3fb": "0xEC44",
    "1f939_1f3fb_200d_2640": "0xEC45",
    "1f939_1f3fb_200d_2642": "0xEC46",
    "1f939_1f3fc": "0xEC47",
    "1f939_1f3fc_200d_2640": "0xEC48",
    "1f939_1f3fc_200d_2642": "0xEC49",
    "1f939_1f3fd": "0xEC4A",
    "1f939_1f3fd_200d_2640": "0xEC4B",
    "1f939_1f3fd_200d_2642": "0xEC4C",
    "1f939_1f3fe": "0xEC4D",
    "1f939_1f3fe_200d_2640": "0xEC4E",
    "1f939_1f3fe_200d_2642": "0xEC4F",
    "1f939_1f3ff": "0xEC50",
    "1f939_1f3ff_200d_2640": "0xEC51",
    "1f939_1f3ff_200d_2642": "0xEC52",
    "1f939_200d_2640": "0xEC53",
    "1f939_200d_2642": "0xEC54",
    "1f93a": "0xEC55",
    "1f93c": "0xEC56",
    "1f93c_1f3fb": "0xEC57",
    "1f93c_1f3fb_200d_2640": "0xEC58",
    "1f93c_1f3fb_200d_2642": "0xEC59",
    "1f93c_1f3fc": "0xEC5A",
    "1f93c_1f3fc_200d_2640": "0xEC5B",
    "1f93c_1f3fc_200d_2642": "0xEC5C",
    "1f93c_1f3fd": "0xEC5D",
    "1f93c_1f3fd_200d_2640": "0xEC5E",
    "1f93c_1f3fd_200d_2642": "0xEC5F",
    "1f93c_1f3fe": "0xEC60",
    "1f93c_1f3fe_200d_2640": "0xEC61",
    "1f93c_1f3fe_200d_2642": "0xEC62",
    "1f93c_1f3ff": "0xEC63",
    "1f93c_1f3ff_200d_2640": "0xEC64",
    "1f93c_1f3ff_200d_2642": "0xEC65",
    "1f93c_200d_2640": "0xEC66",
    "1f93c_200d_2642": "0xEC67",
    "1f93d": "0xEC68",
    "1f93d_1f3fb": "0xEC69",
    "1f93d_1f3fb_200d_2640": "0xEC6A",
    "1f93d_1f3fb_200d_2642": "0xEC6B",
    "1f93d_1f3fc": "0xEC6C",
    "1f93d_1f3fc_200d_2640": "0xEC6D",
    "1f93d_1f3fc_200d_2642": "0xEC6E",
    "1f93d_1f3fd": "0xEC6F",
    "1f93d_1f3fd_200d_2640": "0xEC70",
    "1f93d_1f3fd_200d_2642": "0xEC71",
    "1f93d_1f3fe": "0xEC72",
    "1f93d_1f3fe_200d_2640": "0xEC73",
    "1f93d_1f3fe_200d_2642": "0xEC74",
    "1f93d_1f3ff": "0xEC75",
    "1f93d_1f3ff_200d_2640": "0xEC76",
    "1f93d_1f3ff_200d_2642": "0xEC77",
    "1f93d_200d_2640": "0xEC78",
    "1f93d_200d_2642": "0xEC79",
    "1f93e": "0xEC7A",
    "1f93e_1f3fb": "0xEC7B",
    "1f93e_1f3fb_200d_2640": "0xEC7C",
    "1f93e_1f3fb_200d_2642": "0xEC7D",
    "1f93e_1f3fc": "0xEC7E",
    "1f93e_1f3fc_200d_2640": "0xEC7F",
    "1f93e_1f3fc_200d_2642": "0xEC80",
    "1f93e_1f3fd": "0xEC81",
    "1f93e_1f3fd_200d_2640": "0xEC82",
    "1f93e_1f3fd_200d_2642": "0xEC83",
    "1f93e_1f3fe": "0xEC84",
    "1f93e_1f3fe_200d_2640": "0xEC85",
    "1f93e_1f3fe_200d_2642": "0xEC86",
    "1f93e_1f3ff": "0xEC87",
    "1f93e_1f3ff_200d_2640": "0xEC88",
    "1f93e_1f3ff_200d_2642": "0xEC89",
    "1f93e_200d_2640": "0xEC8A",
    "1f93e_200d_2642": "0xEC8B",
    "1f93f": "0xEC8C",
    "1f940": "0xEC8D",
    "1f941": "0xEC8E",
    "1f942": "0xEC8F",
    "1f943": "0xEC90",
    "1f944": "0xEC91",
    "1f945": "0xEC92",
    "1f947": "0xEC93",
    "1f948": "0xEC94",
    "1f949": "0xEC95",
    "1f94a": "0xEC96",
    "1f94b": "0xEC97",
    "1f94c": "0xEC98",
    "1f94d": "0xEC99",
    "1f94e": "0xEC9A",
    "1f94f": "0xEC9B",
    "1f950": "0xEC9C",
    "1f951": "0xEC9D",
    "1f952": "0xEC9E",
    "1f953": "0xEC9F",
    "1f954": "0xECA0",
    "1f955": "0xECA1",
    "1f956": "0xECA2",
    "1f957": "0xECA3",
    "1f958": "0xECA4",
    "1f959": "0xECA5",
    "1f95a": "0xECA6",
    "1f95b": "0xECA7",
    "1f95c": "0xECA8",
    "1f95d": "0xECA9",
    "1f95e": "0xECAA",
    "1f95f": "0xECAB",
    "1f960": "0xECAC",
    "1f961": "0xECAD",
    "1f962": "0xECAE",
    "1f963": "0xECAF",
    "1f964": "0xECB0",
    "1f965": "0xECB1",
    "1f966": "0xECB2",
    "1f967": "0xECB3",
    "1f968": "0xECB4",
    "1f969": "0xECB5",
    "1f96a": "0xECB6",
    "1f96b": "0xECB7",
    "1f96c": "0xECB8",
    "1f96d": "0xECB9",
    "1f96e": "0xECBA",
    "1f96f": "0xECBB",
    "1f970": "0xECBC",
    "1f971": "0xECBD",
    "1f972": "0xECBE",
    "1f973": "0xECBF",
    "1f974": "0xECC0",
    "1f975": "0xECC1",
    "1f976": "0xECC2",
    "1f977": "0xECC3",
    "1f977_1f3fb": "0xECC4",
    "1f977_1f3fc": "0xECC5",
    "1f977_1f3fd": "0xECC6",
    "1f977_1f3fe": "0xECC7",
    "1f977_1f3ff": "0xECC8",
    "1f978": "0xECC9",
    "1f979": "0xECCA",
    "1f97a": "0xECCB",
    "1f97b": "0xECCC",
    "1f97c": "0xECCD",
    "1f97d": "0xECCE",
    "1f97e": "0xECCF",
    "1f97f": "0xECD0",
    "1f980": "0xECD1",
    "1f981": "0xECD2",
    "1f982": "0xECD3",
    "1f983": "0xECD4",
    "1f984": "0xECD5",
    "1f985": "0xECD6",
    "1f986": "0xECD7",
    "1f987": "0xECD8",
    "1f988": "0xECD9",
    "1f989": "0xECDA",
    "1f98a": "0xECDB",
    "1f98b": "0xECDC",
    "1f98c": "0xECDD",
    "1f98d": "0xECDE",
    "1f98e": "0xECDF",
    "1f98f": "0xECE0",
    "1f990": "0xECE1",
    "1f991": "0xECE2",
    "1f992": "0xECE3",
    "1f993": "0xECE4",
    "1f994": "0xECE5",
    "1f995": "0xECE6",
    "1f996": "0xECE7",
    "1f997": "0xECE8",
    "1f998": "0xECE9",
    "1f999": "0xECEA",
    "1f99a": "0xECEB",
    "1f99b": "0xECEC",
    "1f99c": "0xECED",
    "1f99d": "0xECEE",
    "1f99e": "0xECEF",
    "1f99f": "0xECF0",
    "1f9a0": "0xECF1",
    "1f9a1": "0xECF2",
    "1f9a2": "0xECF3",
    "1f9a3": "0xECF4",
    "1f9a4": "0xECF5",
    "1f9a5": "0xECF6",
    "1f9a6": "0xECF7",
    "1f9a7": "0xECF8",
    "1f9a8": "0xECF9",
    "1f9a9": "0xECFA",
    "1f9aa": "0xECFB",
    "1f9ab": "0xECFC",
    "1f9ac": "0xECFD",
    "1f9ad": "0xECFE",
    "1f9ae": "0xECFF",
    "1f9af": "0xED00",
    "1f9b0": "0xED01",
    "1f9b1": "0xED02",
    "1f9b2": "0xED03",
    "1f9b3": "0xED04",
    "1f9b4": "0xED05",
    "1f9b5": "0xED06",
    "1f9b5_1f3fb": "0xED07",
    "1f9b5_1f3fc": "0xED08",
    "1f9b5_1f3fd": "0xED09",
    "1f9b5_1f3fe": "0xED0A",
    "1f9b5_1f3ff": "0xED0B",
    "1f9b6": "0xED0C",
    "1f9b6_1f3fb": "0xED0D",
    "1f9b6_1f3fc": "0xED0E",
    "1f9b6_1f3fd": "0xED0F",
    "1f9b6_1f3fe": "0xED10",
    "1f9b6_1f3ff": "0xED11",
    "1f9b7": "0xED12",
    "1f9b8": "0xED13",
    "1f9b8_1f3fb": "0xED14",
    "1f9b8_1f3fb_200d_2640": "0xED15",
    "1f9b8_1f3fb_200d_2642": "0xED16",
    "1f9b8_1f3fc": "0xED17",
    "1f9b8_1f3fc_200d_2640": "0xED18",
    "1f9b8_1f3fc_200d_2642": "0xED19",
    "1f9b8_1f3fd": "0xED1A",
    "1f9b8_1f3fd_200d_2640": "0xED1B",
    "1f9b8_1f3fd_200d_2642": "0xED1C",
    "1f9b8_1f3fe": "0xED1D",
    "1f9b8_1f3fe_200d_2640": "0xED1E",
    "1f9b8_1f3fe_200d_2642": "0xED1F",
    "1f9b8_1f3ff": "0xED20",
    "1f9b8_1f3ff_200d_2640": "0xED21",
    "1f9b8_1f3ff_200d_2642": "0xED22",
    "1f9b8_200d_2640": "0xED23",
    "1f9b8_200d_2642": "0xED24",
    "1f9b9": "0xED25",
    "1f9b9_1f3fb": "0xED26",
    "1f9b9_1f3fb_200d_2640": "0xED27",
    "1f9b9_1f3fb_200d_2642": "0xED28",
    "1f9b9_1f3fc": "0xED29",
    "1f9b9_1f3fc_200d_2640": "0xED2A",
    "1f9b9_1f3fc_200d_2642": "0xED2B",
    "1f9b9_1f3fd": "0xED2C",
    "1f9b9_1f3fd_200d_2640": "0xED2D",
    "1f9b9_1f3fd_200d_2642": "0xED2E",
    "1f9b9_1f3fe": "0xED2F",
    "1f9b9_1f3fe_200d_2640": "0xED30",
    "1f9b9_1f3fe_200d_2642": "0xED31",
    "1f9b9_1f3ff": "0xED32",
    "1f9b9_1f3ff_200d_2640": "0xED33",
    "1f9b9_1f3ff_200d_2642": "0xED34",
    "1f9b9_200d_2640": "0xED35",
    "1f9b9_200d_2642": "0xED36",
    "1f9ba": "0xED37",
    "1f9bb": "0xED38",
    "1f9bb_1f3fb": "0xED39",
    "1f9bb_1f3fc": "0xED3A",
    "1f9bb_1f3fd": "0xED3B",
    "1f9bb_1f3fe": "0xED3C",
    "1f9bb_1f3ff": "0xED3D",
    "1f9bc": "0xED3E",
    "1f9bd": "0xED3F",
    "1f9be": "0xED40",
    "1f9bf": "0xED41",
    "1f9c0": "0xED42",
    "1f9c1": "0xED43",
    "1f9c2": "0xED44",
    "1f9c3": "0xED45",
    "1f9c4": "0xED46",
    "1f9c5": "0xED47",
    "1f9c6": "0xED48",
    "1f9c7": "0xED49",
    "1f9c8": "0xED4A",
    "1f9c9": "0xED4B",
    "1f9ca": "0xED4C",
    "1f9cb": "0xED4D",
    "1f9cc": "0xED4E",
    "1f9cd": "0xED4F",
    "1f9cd_1f3fb": "0xED50",
    "1f9cd_1f3fb_200d_2640": "0xED51",
    "1f9cd_1f3fb_200d_2642": "0xED52",
    "1f9cd_1f3fc": "0xED53",
    "1f9cd_1f3fc_200d_2640": "0xED54",
    "1f9cd_1f3fc_200d_2642": "0xED55",
    "1f9cd_1f3fd": "0xED56",
    "1f9cd_1f3fd_200d_2640": "0xED57",
    "1f9cd_1f3fd_200d_2642": "0xED58",
    "1f9cd_1f3fe": "0xED59",
    "1f9cd_1f3fe_200d_2640": "0xED5A",
    "1f9cd_1f3fe_200d_2642": "0xED5B",
    "1f9cd_1f3ff": "0xED5C",
    "1f9cd_1f3ff_200d_2640": "0xED5D",
    "1f9cd_1f3ff_200d_2642": "0xED5E",
    "1f9cd_200d_2640": "0xED5F",
    "1f9cd_200d_2642": "0xED60",
    "1f9ce": "0xED61",
    "1f9ce_1f3fb": "0xED62",
    "1f9ce_1f3fb_200d_2640": "0xED63",
    "1f9ce_1f3fb_200d_2640_200d_27a1": "0xED64",
    "1f9ce_1f3fb_200d_2642": "0xED65",
    "1f9ce_1f3fb_200d_2642_200d_27a1": "0xED66",
    "1f9ce_1f3fb_200d_27a1": "0xED67",
    "1f9ce_1f3fc": "0xED68",
    "1f9ce_1f3fc_200d_2640": "0xED69",
    "1f9ce_1f3fc_200d_2640_200d_27a1": "0xED6A",
    "1f9ce_1f3fc_200d_2642": "0xED6B",
    "1f9ce_1f3fc_200d_2642_200d_27a1": "0xED6C",
    "1f9ce_1f3fc_200d_27a1": "0xED6D",
    "1f9ce_1f3fd": "0xED6E",
    "1f9ce_1f3fd_200d_2640": "0xED6F",
    "1f9ce_1f3fd_200d_2640_200d_27a1": "0xED70",
    "1f9ce_1f3fd_200d_2642": "0xED71",
    "1f9ce_1f3fd_200d_2642_200d_27a1": "0xED72",
    "1f9ce_1f3fd_200d_27a1": "0xED73",
    "1f9ce_1f3fe": "0xED74",
    "1f9ce_1f3fe_200d_2640": "0xED75",
    "1f9ce_1f3fe_200d_2640_200d_27a1": "0xED76",
    "1f9ce_1f3fe_200d_2642": "0xED77",
    "1f9ce_1f3fe_200d_2642_200d_27a1": "0xED78",
    "1f9ce_1f3fe_200d_27a1": "0xED79",
    "1f9ce_1f3ff": "0xED7A",
    "1f9ce_1f3ff_200d_2640": "0xED7B",
    "1f9ce_1f3ff_200d_2640_200d_27a1": "0xED7C",
    "1f9ce_1f3ff_200d_2642": "0xED7D",
    "1f9ce_1f3ff_200d_2642_200d_27a1": "0xED7E",
    "1f9ce_1f3ff_200d_27a1": "0xED7F",
    "1f9ce_200d_2640": "0xED80",
    "1f9ce_200d_2640_200d_27a1": "0xED81",
    "1f9ce_200d_2642": "0xED82",
    "1f9ce_200d_2642_200d_27a1": "0xED83",
    "1f9ce_200d_27a1": "0xED84",
    "1f9cf": "0xED85",
    "1f9cf_1f3fb": "0xED86",
    "1f9cf_1f3fb_200d_2640": "0xED87",
    "1f9cf_1f3fb_200d_2642": "0xED88",
    "1f9cf_1f3fc": "0xED89",
    "1f9cf_1f3fc_200d_2640": "0xED8A",
    "1f9cf_1f3fc_200d_2642": "0xED8B",
    "1f9cf_1f3fd": "0xED8C",
    "1f9cf_1f3fd_200d_2640": "0xED8D",
    "1f9cf_1f3fd_200d_2642": "0xED8E",
    "1f9cf_1f3fe": "0xED8F",
    "1f9cf_1f3fe_200d_2640": "0xED90",
    "1f9cf_1f3fe_200d_2642": "0xED91",
    "1f9cf_1f3ff": "0xED92",
    "1f9cf_1f3ff_200d_2640": "0xED93",
    "1f9cf_1f3ff_200d_2642": "0xED94",
    "1f9cf_200d_2640": "0xED95",
    "1f9cf_200d_2642": "0xED96",
    "1f9d0": "0xED97",
    "1f9d1": "0xED98",
    "1f9d1_1f3fb": "0xED99",
    "1f9d1_1f3fb_200d_1f33e": "0xED9A",
    "1f9d1_1f3fb_200d_1f373": "0xED9B",
    "1f9d1_1f3fb_200d_1f37c": "0xED9C",
    "1f9d1_1f3fb_200d_1f384": "0xED9D",
    "1f9d1_1f3fb_200d_1f393": "0xED9E",
    "1f9d1_1f3fb_200d_1f3a4": "0xED9F",
    "1f9d1_1f3fb_200d_1f3a8": "0xEDA0",
    "1f9d1_1f3fb_200d_1f3eb": "0xEDA1",
    "1f9d1_1f3fb_200d_1f3ed": "0xEDA2",
    "1f9d1_1f3fb_200d_1f4bb": "0xEDA3",
    "1f9d1_1f3fb_200d_1f4bc": "0xEDA4",
    "1f9d1_1f3fb_200d_1f527": "0xEDA5",
    "1f9d1_1f3fb_200d_1f52c": "0xEDA6",
    "1f9d1_1f3fb_200d_1f680": "0xEDA7",
    "1f9d1_1f3fb_200d_1f692": "0xEDA8",
    "1f9d1_1f3fb_200d_1f91d_200d_1f9d1_1f3fb": "0xEDA9",
    "1f9d1_1f3fb_200d_1f91d_200d_1f9d1_1f3fc": "0xEDAA",
    "1f9d1_1f3fb_200d_1f91d_200d_1f9d1_1f3fd": "0xEDAB",
    "1f9d1_1f3fb_200d_1f91d_200d_1f9d1_1f3fe": "0xEDAC",
    "1f9d1_1f3fb_200d_1f91d_200d_1f9d1_1f3ff": "0xEDAD",
    "1f9d1_1f3fb_200d_1f9af": "0xEDAE",
    "1f9d1_1f3fb_200d_1f9af_200d_27a1": "0xEDAF",
    "1f9d1_1f3fb_200d_1f9b0": "0xEDB0",
    "1f9d1_1f3fb_200d_1f9b1": "0xEDB1",
    "1f9d1_1f3fb_200d_1f9b2": "0xEDB2",
    "1f9d1_1f3fb_200d_1f9b3": "0xEDB3",
    "1f9d1_1f3fb_200d_1f9bc": "0xEDB4",
    "1f9d1_1f3fb_200d_1f9bc_200d_27a1": "0xEDB5",
    "1f9d1_1f3fb_200d_1f9bd": "0xEDB6",
    "1f9d1_1f3fb_200d_1f9bd_200d_27a1": "0xEDB7",
    "1f9d1_1f3fb_200d_2695": "0xEDB8",
    "1f9d1_1f3fb_200d_2696": "0xEDB9",
    "1f9d1_1f3fb_200d_2708": "0xEDBA",
    "1f9d1_1f3fb_200d_2764_200d_1f48b_200d_1f9d1_1f3fc": "0xEDBB",
    "1f9d1_1f3fb_200d_2764_200d_1f48b_200d_1f9d1_1f3fd": "0xEDBC",
    "1f9d1_1f3fb_200d_2764_200d_1f48b_200d_1f9d1_1f3fe": "0xEDBD",
    "1f9d1_1f3fb_200d_2764_200d_1f48b_200d_1f9d1_1f3ff": "0xEDBE",
    "1f9d1_1f3fb_200d_2764_200d_1f9d1_1f3fc": "0xEDBF",
    "1f9d1_1f3fb_200d_2764_200d_1f9d1_1f3fd": "0xEDC0",
    "1f9d1_1f3fb_200d_2764_200d_1f9d1_1f3fe": "0xEDC1",
    "1f9d1_1f3fb_200d_2764_200d_1f9d1_1f3ff": "0xEDC2",
    "1f9d1_1f3fc": "0xEDC3",
    "1f9d1_1f3fc_200d_1f33e": "0xEDC4",
    "1f9d1_1f3fc_200d_1f373": "0xEDC5",
    "1f9d1_1f3fc_200d_1f37c": "0xEDC6",
    "1f9d1_1f3fc_200d_1f384": "0xEDC7",
    "1f9d1_1f3fc_200d_1f393": "0xEDC8",
    "1f9d1_1f3fc_200d_1f3a4": "0xEDC9",
    "1f9d1_1f3fc_200d_1f3a8": "0xEDCA",
    "1f9d1_1f3fc_200d_1f3eb": "0xEDCB",
    "1f9d1_1f3fc_200d_1f3ed": "0xEDCC",
    "1f9d1_1f3fc_200d_1f4bb": "0xEDCD",
    "1f9d1_1f3fc_200d_1f4bc": "0xEDCE",
    "1f9d1_1f3fc_200d_1f527": "0xEDCF",
    "1f9d1_1f3fc_200d_1f52c": "0xEDD0",
    "1f9d1_1f3fc_200d_1f680": "0xEDD1",
    "1f9d1_1f3fc_200d_1f692": "0xEDD2",
    "1f9d1_1f3fc_200d_1f91d_200d_1f9d1_1f3fb": "0xEDD3",
    "1f9d1_1f3fc_200d_1f91d_200d_1f9d1_1f3fc": "0xEDD4",
    "1f9d1_1f3fc_200d_1f91d_200d_1f9d1_1f3fd": "0xEDD5",
    "1f9d1_1f3fc_200d_1f91d_200d_1f9d1_1f3fe": "0xEDD6",
    "1f9d1_1f3fc_200d_1f91d_200d_1f9d1_1f3ff": "0xEDD7",
    "1f9d1_1f3fc_200d_1f9af": "0xEDD8",
    "1f9d1_1f3fc_200d_1f9af_200d_27a1": "0xEDD9",
    "1f9d1_1f3fc_200d_1f9b0": "0xEDDA",
    "1f9d1_1f3fc_200d_1f9b1": "0xEDDB",
    "1f9d1_1f3fc_200d_1f9b2": "0xEDDC",
    "1f9d1_1f3fc_200d_1f9b3": "0xEDDD",
    "1f9d1_1f3fc_200d_1f9bc": "0xEDDE",
    "1f9d1_1f3fc_200d_1f9bc_200d_27a1": "0xEDDF",
    "1f9d1_1f3fc_200d_1f9bd": "0xEDE0",
    "1f9d1_1f3fc_200d_1f9bd_200d_27a1": "0xEDE1",
    "1f9d1_1f3fc_200d_2695": "0xEDE2",
    "1f9d1_1f3fc_200d_2696": "0xEDE3",
    "1f9d1_1f3fc_200d_2708": "0xEDE4",
    "1f9d1_1f3fc_200d_2764_200d_1f48b_200d_1f9d1_1f3fb": "0xEDE5",
    "1f9d1_1f3fc_200d_2764_200d_1f48b_200d_1f9d1_1f3fd": "0xEDE6",
    "1f9d1_1f3fc_200d_2764_200d_1f48b_200d_1f9d1_1f3fe": "0xEDE7",
    "1f9d1_1f3fc_200d_2764_200d_1f48b_200d_1f9d1_1f3ff": "0xEDE8",
    "1f9d1_1f3fc_200d_2764_200d_1f9d1_1f3fb": "0xEDE9",
    "1f9d1_1f3fc_200d_2764_200d_1f9d1_1f3fd": "0xEDEA",
    "1f9d1_1f3fc_200d_2764_200d_1f9d1_1f3fe": "0xEDEB",
    "1f9d1_1f3fc_200d_2764_200d_1f9d1_1f3ff": "0xEDEC",
    "1f9d1_1f3fd": "0xEDED",
    "1f9d1_1f3fd_200d_1f33e": "0xEDEE",
    "1f9d1_1f3fd_200d_1f373": "0xEDEF",
    "1f9d1_1f3fd_200d_1f37c": "0xEDF0",
    "1f9d1_1f3fd_200d_1f384": "0xEDF1",
    "1f9d1_1f3fd_200d_1f393": "0xEDF2",
    "1f9d1_1f3fd_200d_1f3a4": "0xEDF3",
    "1f9d1_1f3fd_200d_1f3a8": "0xEDF4",
    "1f9d1_1f3fd_200d_1f3eb": "0xEDF5",
    "1f9d1_1f3fd_200d_1f3ed": "0xEDF6",
    "1f9d1_1f3fd_200d_1f4bb": "0xEDF7",
    "1f9d1_1f3fd_200d_1f4bc": "0xEDF8",
    "1f9d1_1f3fd_200d_1f527": "0xEDF9",
    "1f9d1_1f3fd_200d_1f52c": "0xEDFA",
    "1f9d1_1f3fd_200d_1f680": "0xEDFB",
    "1f9d1_1f3fd_200d_1f692": "0xEDFC",
    "1f9d1_1f3fd_200d_1f91d_200d_1f9d1_1f3fb": "0xEDFD",
    "1f9d1_1f3fd_200d_1f91d_200d_1f9d1_1f3fc": "0xEDFE",
    "1f9d1_1f3fd_200d_1f91d_200d_1f9d1_1f3fd": "0xEDFF",
    "1f9d1_1f3fd_200d_1f91d_200d_1f9d1_1f3fe": "0xEE00",
    "1f9d1_1f3fd_200d_1f91d_200d_1f9d1_1f3ff": "0xEE01",
    "1f9d1_1f3fd_200d_1f9af": "0xEE02",
    "1f9d1_1f3fd_200d_1f9af_200d_27a1": "0xEE03",
    "1f9d1_1f3fd_200d_1f9b0": "0xEE04",
    "1f9d1_1f3fd_200d_1f9b1": "0xEE05",
    "1f9d1_1f3fd_200d_1f9b2": "0xEE06",
    "1f9d1_1f3fd_200d_1f9b3": "0xEE07",
    "1f9d1_1f3fd_200d_1f9bc": "0xEE08",
    "1f9d1_1f3fd_200d_1f9bc_200d_27a1": "0xEE09",
    "1f9d1_1f3fd_200d_1f9bd": "0xEE0A",
    "1f9d1_1f3fd_200d_1f9bd_200d_27a1": "0xEE0B",
    "1f9d1_1f3fd_200d_2695": "0xEE0C",
    "1f9d1_1f3fd_200d_2696": "0xEE0D",
    "1f9d1_1f3fd_200d_2708": "0xEE0E",
    "1f9d1_1f3fd_200d_2764_200d_1f48b_200d_1f9d1_1f3fb": "0xEE0F",
    "1f9d1_1f3fd_200d_2764_200d_1f48b_200d_1f9d1_1f3fc": "0xEE10",
    "1f9d1_1f3fd_200d_2764_200d_1f48b_200d_1f9d1_1f3fe": "0xEE11",
    "1f9d1_1f3fd_200d_2764_200d_1f48b_200d_1f9d1_1f3ff": "0xEE12",
    "1f9d1_1f3fd_200d_2764_200d_1f9d1_1f3fb": "0xEE13",
    "1f9d1_1f3fd_200d_2764_200d_1f9d1_1f3fc": "0xEE14",
    "1f9d1_1f3fd_200d_2764_200d_1f9d1_1f3fe": "0xEE15",
    "1f9d1_1f3fd_200d_2764_200d_1f9d1_1f3ff": "0xEE16",
    "1f9d1_1f3fe": "0xEE17",
    "1f9d1_1f3fe_200d_1f33e": "0xEE18",
    "1f9d1_1f3fe_200d_1f373": "0xEE19",
    "1f9d1_1f3fe_200d_1f37c": "0xEE1A",
    "1f9d1_1f3fe_200d_1f384": "0xEE1B",
    "1f9d1_1f3fe_200d_1f393": "0xEE1C",
    "1f9d1_1f3fe_200d_1f3a4": "0xEE1D",
    "1f9d1_1f3fe_200d_1f3a8": "0xEE1E",
    "1f9d1_1f3fe_200d_1f3eb": "0xEE1F",
    "1f9d1_1f3fe_200d_1f3ed": "0xEE20",
    "1f9d1_1f3fe_200d_1f4bb": "0xEE21",
    "1f9d1_1f3fe_200d_1f4bc": "0xEE22",
    "1f9d1_1f3fe_200d_1f527": "0xEE23",
    "1f9d1_1f3fe_200d_1f52c": "0xEE24",
    "1f9d1_1f3fe_200d_1f680": "0xEE25",
    "1f9d1_1f3fe_200d_1f692": "0xEE26",
    "1f9d1_1f3fe_200d_1f91d_200d_1f9d1_1f3fb": "0xEE27",
    "1f9d1_1f3fe_200d_1f91d_200d_1f9d1_1f3fc": "0xEE28",
    "1f9d1_1f3fe_200d_1f91d_200d_1f9d1_1f3fd": "0xEE29",
    "1f9d1_1f3fe_200d_1f91d_200d_1f9d1_1f3fe": "0xEE2A",
    "1f9d1_1f3fe_200d_1f91d_200d_1f9d1_1f3ff": "0xEE2B",
    "1f9d1_1f3fe_200d_1f9af": "0xEE2C",
    "1f9d1_1f3fe_200d_1f9af_200d_27a1": "0xEE2D",
    "1f9d1_1f3fe_200d_1f9b0": "0xEE2E",
    "1f9d1_1f3fe_200d_1f9b1": "0xEE2F",
    "1f9d1_1f3fe_200d_1f9b2": "0xEE30",
    "1f9d1_1f3fe_200d_1f9b3": "0xEE31",
    "1f9d1_1f3fe_200d_1f9bc": "0xEE32",
    "1f9d1_1f3fe_200d_1f9bc_200d_27a1": "0xEE33",
    "1f9d1_1f3fe_200d_1f9bd": "0xEE34",
    "1f9d1_1f3fe_200d_1f9bd_200d_27a1": "0xEE35",
    "1f9d1_1f3fe_200d_2695": "0xEE36",
    "1f9d1_1f3fe_200d_2696": "0xEE37",
    "1f9d1_1f3fe_200d_2708": "0xEE38",
    "1f9d1_1f3fe_200d_2764_200d_1f48b_200d_1f9d1_1f3fb": "0xEE39",
    "1f9d1_1f3fe_200d_2764_200d_1f48b_200d_1f9d1_1f3fc": "0xEE3A",
    "1f9d1_1f3fe_200d_2764_200d_1f48b_200d_1f9d1_1f3fd": "0xEE3B",
    "1f9d1_1f3fe_200d_2764_200d_1f48b_200d_1f9d1_1f3ff": "0xEE3C",
    "1f9d1_1f3fe_200d_2764_200d_1f9d1_1f3fb": "0xEE3D",
    "1f9d1_1f3fe_200d_2764_200d_1f9d1_1f3fc": "0xEE3E",
    "1f9d1_1f3fe_200d_2764_200d_1f9d1_1f3fd": "0xEE3F",
    "1f9d1_1f3fe_200d_2764_200d_1f9d1_1f3ff": "0xEE40",
    "1f9d1_1f3ff": "0xEE41",
    "1f9d1_1f3ff_200d_1f33e": "0xEE42",
    "1f9d1_1f3ff_200d_1f373": "0xEE43",
    "1f9d1_1f3ff_200d_1f37c": "0xEE44",
    "1f9d1_1f3ff_200d_1f384": "0xEE45",
    "1f9d1_1f3ff_200d_1f393": "0xEE46",
    "1f9d1_1f3ff_200d_1f3a4": "0xEE47",
    "1f9d1_1f3ff_200d_1f3a8": "0xEE48",
    "1f9d1_1f3ff_200d_1f3eb": "0xEE49",
    "1f9d1_1f3ff_200d_1f3ed": "0xEE4A",
    "1f9d1_1f3ff_200d_1f4bb": "0xEE4B",
    "1f9d1_1f3ff_200d_1f4bc": "0xEE4C",
    "1f9d1_1f3ff_200d_1f527": "0xEE4D",
    "1f9d1_1f3ff_200d_1f52c": "0xEE4E",
    "1f9d1_1f3ff_200d_1f680": "0xEE4F",
    "1f9d1_1f3ff_200d_1f692": "0xEE50",
    "1f9d1_1f3ff_200d_1f91d_200d_1f9d1_1f3fb": "0xEE51",
    "1f9d1_1f3ff_200d_1f91d_200d_1f9d1_1f3fc": "0xEE52",
    "1f9d1_1f3ff_200d_1f91d_200d_1f9d1_1f3fd": "0xEE53",
    "1f9d1_1f3ff_200d_1f91d_200d_1f9d1_1f3fe": "0xEE54",
    "1f9d1_1f3ff_200d_1f91d_200d_1f9d1_1f3ff": "0xEE55",
    "1f9d1_1f3ff_200d_1f9af": "0xEE56",
    "1f9d1_1f3ff_200d_1f9af_200d_27a1": "0xEE57",
    "1f9d1_1f3ff_200d_1f9b0": "0xEE58",
    "1f9d1_1f3ff_200d_1f9b1": "0xEE59",
    "1f9d1_1f3ff_200d_1f9b2": "0xEE5A",
    "1f9d1_1f3ff_200d_1f9b3": "0xEE5B",
    "1f9d1_1f3ff_200d_1f9bc": "0xEE5C",
    "1f9d1_1f3ff_200d_1f9bc_200d_27a1": "0xEE5D",
    "1f9d1_1f3ff_200d_1f9bd": "0xEE5E",
    "1f9d1_1f3ff_200d_1f9bd_200d_27a1": "0xEE5F",
    "1f9d1_1f3ff_200d_2695": "0xEE60",
    "1f9d1_1f3ff_200d_2696": "0xEE61",
    "1f9d1_1f3ff_200d_2708": "0xEE62",
    "1f9d1_1f3ff_200d_2764_200d_1f48b_200d_1f9d1_1f3fb": "0xEE63",
    "1f9d1_1f3ff_200d_2764_200d_1f48b_200d_1f9d1_1f3fc": "0xEE64",
    "1f9d1_1f3ff_200d_2764_200d_1f48b_200d_1f9d1_1f3fd": "0xEE65",
    "1f9d1_1f3ff_200d_2764_200d_1f48b_200d_1f9d1_1f3fe": "0xEE66",
    "1f9d1_1f3ff_200d_2764_200d_1f9d1_1f3fb": "0xEE67",
    "1f9d1_1f3ff_200d_2764_200d_1f9d1_1f3fc": "0xEE68",
    "1f9d1_1f3ff_200d_2764_200d_1f9d1_1f3fd": "0xEE69",
    "1f9d1_1f3ff_200d_2764_200d_1f9d1_1f3fe": "0xEE6A",
    "1f9d1_200d_1f33e": "0xEE6B",
    "1f9d1_200d_1f373": "0xEE6C",
    "1f9d1_200d_1f37c": "0xEE6D",
    "1f9d1_200d_1f384": "0xEE6E",
    "1f9d1_200d_1f393": "0xEE6F",
    "1f9d1_200d_1f3a4": "0xEE70",
    "1f9d1_200d_1f3a8": "0xEE71",
    "1f9d1_200d_1f3eb": "0xEE72",
    "1f9d1_200d_1f3ed": "0xEE73",
    "1f9d1_200d_1f4bb": "0xEE74",
    "1f9d1_200d_1f4bc": "0xEE75",
    "1f9d1_200d_1f527": "0xEE76",
    "1f9d1_200d_1f52c": "0xEE77",
    "1f9d1_200d_1f680": "0xEE78",
    "1f9d1_200d_1f692": "0xEE79",
    "1f9d1_200d_1f91d_200d_1f9d1": "0xEE7A",
    "1f9d1_200d_1f9af": "0xEE7B",
    "1f9d1_200d_1f9af_200d_27a1": "0xEE7C",
    "1f9d1_200d_1f9b0": "0xEE7D",
    "1f9d1_200d_1f9b1": "0xEE7E",
    "1f9d1_200d_1f9b2": "0xEE7F",
    "1f9d1_200d_1f9b3": "0xEE80",
    "1f9d1_200d_1f9bc": "0xEE81",
    "1f9d1_200d_1f9bc_200d_27a1": "0xEE82",
    "1f9d1_200d_1f9bd": "0xEE83",
    "1f9d1_200d_1f9bd_200d_27a1": "0xEE84",
    "1f9d1_200d_1f9d1_200d_1f9d2": "0xEE85",
    "1f9d1_200d_1f9d1_200d_1f9d2_200d_1f9d2": "0xEE86",
    "1f9d1_200d_1f9d2": "0xEE87",
    "1f9d1_200d_1f9d2_200d_1f9d2": "0xEE88",
    "1f9d1_200d_2695": "0xEE89",
    "1f9d1_200d_2696": "0xEE8A",
    "1f9d1_200d_2708": "0xEE8B",
    "1f9d2": "0xEE8C",
    "1f9d2_1f3fb": "0xEE8D",
    "1f9d2_1f3fc": "0xEE8E",
    "1f9d2_1f3fd": "0xEE8F",
    "1f9d2_1f3fe": "0xEE90",
    "1f9d2_1f3ff": "0xEE91",
    "1f9d3": "0xEE92",
    "1f9d3_1f3fb": "0xEE93",
    "1f9d3_1f3fc": "0xEE94",
    "1f9d3_1f3fd": "0xEE95",
    "1f9d3_1f3fe": "0xEE96",
    "1f9d3_1f3ff": "0xEE97",
    "1f9d4": "0xEE98",
    "1f9d4_1f3fb": "0xEE99",
    "1f9d4_1f3fb_200d_2640": "0xEE9A",
    "1f9d4_1f3fb_200d_2642": "0xEE9B",
    "1f9d4_1f3fc": "0xEE9C",
    "1f9d4_1f3fc_200d_2640": "0xEE9D",
    "1f9d4_1f3fc_200d_2642": "0xEE9E",
    "1f9d4_1f3fd": "0xEE9F",
    "1f9d4_1f3fd_200d_2640": "0xEEA0",
    "1f9d4_1f3fd_200d_2642": "0xEEA1",
    "1f9d4_1f3fe": "0xEEA2",
    "1f9d4_1f3fe_200d_2640": "0xEEA3",
    "1f9d4_1f3fe_200d_2642": "0xEEA4",
    "1f9d4_1f3ff": "0xEEA5",
    "1f9d4_1f3ff_200d_2640": "0xEEA6",
    "1f9d4_1f3ff_200d_2642": "0xEEA7",
    "1f9d4_200d_2640": "0xEEA8",
    "1f9d4_200d_2642": "0xEEA9",
    "1f9d5": "0xEEAA",
    "1f9d5_1f3fb": "0xEEAB",
    "1f9d5_1f3fc": "0xEEAC",
    "1f9d5_1f3fd": "0xEEAD",
    "1f9d5_1f3fe": "0xEEAE",
    "1f9d5_1f3ff": "0xEEAF",
    "1f9d6": "0xEEB0",
    "1f9d6_1f3fb": "0xEEB1",
    "1f9d6_1f3fb_200d_2640": "0xEEB2",
    "1f9d6_1f3fb_200d_2642": "0xEEB3",
    "1f9d6_1f3fc": "0xEEB4",
    "1f9d6_1f3fc_200d_2640": "0xEEB5",
    "1f9d6_1f3fc_200d_2642": "0xEEB6",
    "1f9d6_1f3fd": "0xEEB7",
    "1f9d6_1f3fd_200d_2640": "0xEEB8",
    "1f9d6_1f3fd_200d_2642": "0xEEB9",
    "1f9d6_1f3fe": "0xEEBA",
    "1f9d6_1f3fe_200d_2640": "0xEEBB",
    "1f9d6_1f3fe_200d_2642": "0xEEBC",
    "1f9d6_1f3ff": "0xEEBD",
    "1f9d6_1f3ff_200d_2640": "0xEEBE",
    "1f9d6_1f3ff_200d_2642": "0xEEBF",
    "1f9d6_200d_2640": "0xEEC0",
    "1f9d6_200d_2642": "0xEEC1",
    "1f9d7": "0xEEC2",
    "1f9d7_1f3fb": "0xEEC3",
    "1f9d7_1f3fb_200d_2640": "0xEEC4",
    "1f9d7_1f3fb_200d_2642": "0xEEC5",
    "1f9d7_1f3fc": "0xEEC6",
    "1f9d7_1f3fc_200d_2640": "0xEEC7",
    "1f9d7_1f3fc_200d_2642": "0xEEC8",
    "1f9d7_1f3fd": "0xEEC9",
    "1f9d7_1f3fd_200d_2640": "0xEECA",
    "1f9d7_1f3fd_200d_2642": "0xEECB",
    "1f9d7_1f3fe": "0xEECC",
    "1f9d7_1f3fe_200d_2640": "0xEECD",
    "1f9d7_1f3fe_200d_2642": "0xEECE",
    "1f9d7_1f3ff": "0xEECF",
    "1f9d7_1f3ff_200d_2640": "0xEED0",
    "1f9d7_1f3ff_200d_2642": "0xEED1",
    "1f9d7_200d_2640": "0xEED2",
    "1f9d7_200d_2642": "0xEED3",
    "1f9d8": "0xEED4",
    "1f9d8_1f3fb": "0xEED5",
    "1f9d8_1f3fb_200d_2640": "0xEED6",
    "1f9d8_1f3fb_200d_2642": "0xEED7",
    "1f9d8_1f3fc": "0xEED8",
    "1f9d8_1f3fc_200d_2640": "0xEED9",
    "1f9d8_1f3fc_200d_2642": "0xEEDA",
    "1f9d8_1f3fd": "0xEEDB",
    "1f9d8_1f3fd_200d_2640": "0xEEDC",
    "1f9d8_1f3fd_200d_2642": "0xEEDD",
    "1f9d8_1f3fe": "0xEEDE",
    "1f9d8_1f3fe_200d_2640": "0xEEDF",
    "1f9d8_1f3fe_200d_2642": "0xEEE0",
    "1f9d8_1f3ff": "0xEEE1",
    "1f9d8_1f3ff_200d_2640": "0xEEE2",
    "1f9d8_1f3ff_200d_2642": "0xEEE3",
    "1f9d8_200d_2640": "0xEEE4",
    "1f9d8_200d_2642": "0xEEE5",
    "1f9d9": "0xEEE6",
    "1f9d9_1f3fb": "0xEEE7",
    "1f9d9_1f3fb_200d_2640": "0xEEE8",
    "1f9d9_1f3fb_200d_2642": "0xEEE9",
    "1f9d9_1f3fc": "0xEEEA",
    "1f9d9_1f3fc_200d_2640": "0xEEEB",
    "1f9d9_1f3fc_200d_2642": "0xEEEC",
    "1f9d9_1f3fd": "0xEEED",
    "1f9d9_1f3fd_200d_2640": "0xEEEE",
    "1f9d9_1f3fd_200d_2642": "0xEEEF",
    "1f9d9_1f3fe": "0xEEF0",
    "1f9d9_1f3fe_200d_2640": "0xEEF1",
    "1f9d9_1f3fe_200d_2642": "0xEEF2",
    "1f9d9_1f3ff": "0xEEF3",
    "1f9d9_1f3ff_200d_2640": "0xEEF4",
    "1f9d9_1f3ff_200d_2642": "0xEEF5",
    "1f9d9_200d_2640": "0xEEF6",
    "1f9d9_200d_2642": "0xEEF7",
    "1f9da": "0xEEF8",
    "1f9da_1f3fb": "0xEEF9",
    "1f9da_1f3fb_200d_2640": "0xEEFA",
    "1f9da_1f3fb_200d_2642": "0xEEFB",
    "1f9da_1f3fc": "0xEEFC",
    "1f9da_1f3fc_200d_2640": "0xEEFD",
    "1f9da_1f3fc_200d_2642": "0xEEFE",
    "1f9da_1f3fd": "0xEEFF",
    "1f9da_1f3fd_200d_2640": "0xEF00",
    "1f9da_1f3fd_200d_2642": "0xEF01",
    "1f9da_1f3fe": "0xEF02",
    "1f9da_1f3fe_200d_2640": "0xEF03",
    "1f9da_1f3fe_200d_2642": "0xEF04",
    "1f9da_1f3ff": "0xEF05",
    "1f9da_1f3ff_200d_2640": "0xEF06",
    "1f9da_1f3ff_200d_2642": "0xEF07",
    "1f9da_200d_2640": "0xEF08",
    "1f9da_200d_2642": "0xEF09",
    "1f9db": "0xEF0A",
    "1f9db_1f3fb": "0xEF0B",
    "1f9db_1f3fb_200d_2640": "0xEF0C",
    "1f9db_1f3fb_200d_2642": "0xEF0D",
    "1f9db_1f3fc": "0xEF0E",
    "1f9db_1f3fc_200d_2640": "0xEF0F",
    "1f9db_1f3fc_200d_2642": "0xEF10",
    "1f9db_1f3fd": "0xEF11",
    "1f9db_1f3fd_200d_2640": "0xEF12",
    "1f9db_1f3fd_200d_2642": "0xEF13",
    "1f9db_1f3fe": "0xEF14",
    "1f9db_1f3fe_200d_2640": "0xEF15",
    "1f9db_1f3fe_200d_2642": "0xEF16",
    "1f9db_1f3ff": "0xEF17",
    "1f9db_1f3ff_200d_2640": "0xEF18",
    "1f9db_1f3ff_200d_2642": "0xEF19",
    "1f9db_200d_2640": "0xEF1A",
    "1f9db_200d_2642": "0xEF1B",
    "1f9dc": "0xEF1C",
    "1f9dc_1f3fb": "0xEF1D",
    "1f9dc_1f3fb_200d_2640": "0xEF1E",
    "1f9dc_1f3fb_200d_2642": "0xEF1F",
    "1f9dc_1f3fc": "0xEF20",
    "1f9dc_1f3fc_200d_2640": "0xEF21",
    "1f9dc_1f3fc_200d_2642": "0xEF22",
    "1f9dc_1f3fd": "0xEF23",
    "1f9dc_1f3fd_200d_2640": "0xEF24",
    "1f9dc_1f3fd_200d_2642": "0xEF25",
    "1f9dc_1f3fe": "0xEF26",
    "1f9dc_1f3fe_200d_2640": "0xEF27",
    "1f9dc_1f3fe_200d_2642": "0xEF28",
    "1f9dc_1f3ff": "0xEF29",
    "1f9dc_1f3ff_200d_2640": "0xEF2A",
    "1f9dc_1f3ff_200d_2642": "0xEF2B",
    "1f9dc_200d_2640": "0xEF2C",
    "1f9dc_200d_2642": "0xEF2D",
    "1f9dd": "0xEF2E",
    "1f9dd_1f3fb": "0xEF2F",
    "1f9dd_1f3fb_200d_2640": "0xEF30",
    "1f9dd_1f3fb_200d_2642": "0xEF31",
    "1f9dd_1f3fc": "0xEF32",
    "1f9dd_1f3fc_200d_2640": "0xEF33",
    "1f9dd_1f3fc_200d_2642": "0xEF34",
    "1f9dd_1f3fd": "0xEF35",
    "1f9dd_1f3fd_200d_2640": "0xEF36",
    "1f9dd_1f3fd_200d_2642": "0xEF37",
    "1f9dd_1f3fe": "0xEF38",
    "1f9dd_1f3fe_200d_2640": "0xEF39",
    "1f9dd_1f3fe_200d_2642": "0xEF3A",
    "1f9dd_1f3ff": "0xEF3B",
    "1f9dd_1f3ff_200d_2640": "0xEF3C",
    "1f9dd_1f3ff_200d_2642": "0xEF3D",
    "1f9dd_200d_2640": "0xEF3E",
    "1f9dd_200d_2642": "0xEF3F",
    "1f9de": "0xEF40",
    "1f9de_200d_2640": "0xEF41",
    "1f9de_200d_2642": "0xEF42",
    "1f9df": "0xEF43",
    "1f9df_200d_2640": "0xEF44",
    "1f9df_200d_2642": "0xEF45",
    "1f9e0": "0xEF46",
    "1f9e1": "0xEF47",
    "1f9e2": "0xEF48",
    "1f9e3": "0xEF49",
    "1f9e4": "0xEF4A",
    "1f9e5": "0xEF4B",
    "1f9e6": "0xEF4C",
    "1f9e7": "0xEF4D",
    "1f9e8": "0xEF4E",
    "1f9e9": "0xEF4F",
    "1f9ea": "0xEF50",
    "1f9eb": "0xEF51",
    "1f9ec": "0xEF52",
    "1f9ed": "0xEF53",
    "1f9ee": "0xEF54",
    "1f9ef": "0xEF55",
    "1f9f0": "0xEF56",
    "1f9f1": "0xEF57",
    "1f9f2": "0xEF58",
    "1f9f3": "0xEF59",
    "1f9f4": "0xEF5A",
    "1f9f5": "0xEF5B",
    "1f9f6": "0xEF5C",
    "1f9f7": "0xEF5D",
    "1f9f8": "0xEF5E",
    "1f9f9": "0xEF5F",
    "1f9fa": "0xEF60",
    "1f9fb": "0xEF61",
    "1f9fc": "0xEF62",
    "1f9fd": "0xEF63",
    "1f9fe": "0xEF64",
    "1f9ff": "0xEF65",
    "1fa70": "0xEF66",
    "1fa71": "0xEF67",
    "1fa72": "0xEF68",
    "1fa73": "0xEF69",
    "1fa74": "0xEF6A",
    "1fa75": "0xEF6B",
    "1fa76": "0xEF6C",
    "1fa77": "0xEF6D",
    "1fa78": "0xEF6E",
    "1fa79": "0xEF6F",
    "1fa7a": "0xEF70",
    "1fa7b": "0xEF71",
    "1fa7c": "0xEF72",
    "1fa80": "0xEF73",
    "1fa81": "0xEF74",
    "1fa82": "0xEF75",
    "1fa83": "0xEF76",
    "1fa84": "0xEF77",
    "1fa85": "0xEF78",
    "1fa86": "0xEF79",
    "1fa87": "0xEF7A",
    "1fa88": "0xEF7B",
    "1fa89": "0xEF7C",
    "1fa8f": "0xEF7D",
    "1fa90": "0xEF7E",
    "1fa91": "0xEF7F",
    "1fa92": "0xEF80",
    "1fa93": "0xEF81",
    "1fa94": "0xEF82",
    "1fa95": "0xEF83",
    "1fa96": "0xEF84",
    "1fa97": "0xEF85",
    "1fa98": "0xEF86",
    "1fa99": "0xEF87",
    "1fa9a": "0xEF88",
    "1fa9b": "0xEF89",
    "1fa9c": "0xEF8A",
    "1fa9d": "0xEF8B",
    "1fa9e": "0xEF8C",
    "1fa9f": "0xEF8D",
    "1faa0": "0xEF8E",
    "1faa1": "0xEF8F",
    "1faa2": "0xEF90",
    "1faa3": "0xEF91",
    "1faa4": "0xEF92",
    "1faa5": "0xEF93",
    "1faa6": "0xEF94",
    "1faa7": "0xEF95",
    "1faa8": "0xEF96",
    "1faa9": "0xEF97",
    "1faaa": "0xEF98",
    "1faab": "0xEF99",
    "1faac": "0xEF9A",
    "1faad": "0xEF9B",
    "1faae": "0xEF9C",
    "1faaf": "0xEF9D",
    "1fab0": "0xEF9E",
    "1fab1": "0xEF9F",
    "1fab2": "0xEFA0",
    "1fab3": "0xEFA1",
    "1fab4": "0xEFA2",
    "1fab5": "0xEFA3",
    "1fab6": "0xEFA4",
    "1fab7": "0xEFA5",
    "1fab8": "0xEFA6",
    "1fab9": "0xEFA7",
    "1faba": "0xEFA8",
    "1fabb": "0xEFA9",
    "1fabc": "0xEFAA",
    "1fabd": "0xEFAB",
    "1fabe": "0xEFAC",
    "1fabf": "0xEFAD",
    "1fac0": "0xEFAE",
    "1fac1": "0xEFAF",
    "1fac2": "0xEFB0",
    "1fac3": "0xEFB1",
    "1fac3_1f3fb": "0xEFB2",
    "1fac3_1f3fc": "0xEFB3",
    "1fac3_1f3fd": "0xEFB4",
    "1fac3_1f3fe": "0xEFB5",
    "1fac3_1f3ff": "0xEFB6",
    "1fac4": "0xEFB7",
    "1fac4_1f3fb": "0xEFB8",
    "1fac4_1f3fc": "0xEFB9",
    "1fac4_1f3fd": "0xEFBA",
    "1fac4_1f3fe": "0xEFBB",
    "1fac4_1f3ff": "0xEFBC",
    "1fac5": "0xEFBD",
    "1fac5_1f3fb": "0xEFBE",
    "1fac5_1f3fc": "0xEFBF",
    "1fac5_1f3fd": "0xEFC0",
    "1fac5_1f3fe": "0xEFC1",
    "1fac5_1f3ff": "0xEFC2",
    "1fac6": "0xEFC3",
    "1face": "0xEFC4",
    "1facf": "0xEFC5",
    "1fad0": "0xEFC6",
    "1fad1": "0xEFC7",
    "1fad2": "0xEFC8",
    "1fad3": "0xEFC9",
    "1fad4": "0xEFCA",
    "1fad5": "0xEFCB",
    "1fad6": "0xEFCC",
    "1fad7": "0xEFCD",
    "1fad8": "0xEFCE",
    "1fad9": "0xEFCF",
    "1fada": "0xEFD0",
    "1fadb": "0xEFD1",
    "1fadc": "0xEFD2",
    "1fadf": "0xEFD3",
    "1fae0": "0xEFD4",
    "1fae1": "0xEFD5",
    "1fae2": "0xEFD6",
    "1fae3": "0xEFD7",
    "1fae4": "0xEFD8",
    "1fae5": "0xEFD9",
    "1fae6": "0xEFDA",
    "1fae7": "0xEFDB",
    "1fae8": "0xEFDC",
    "1fae9": "0xEFDD",
    "1faf0": "0xEFDE",
    "1faf0_1f3fb": "0xEFDF",
    "1faf0_1f3fc": "0xEFE0",
    "1faf0_1f3fd": "0xEFE1",
    "1faf0_1f3fe": "0xEFE2",
    "1faf0_1f3ff": "0xEFE3",
    "1faf1": "0xEFE4",
    "1faf1_1f3fb": "0xEFE5",
    "1faf1_1f3fb_200d_1faf2_1f3fc": "0xEFE6",
    "1faf1_1f3fb_200d_1faf2_1f3fd": "0xEFE7",
    "1faf1_1f3fb_200d_1faf2_1f3fe": "0xEFE8",
    "1faf1_1f3fb_200d_1faf2_1f3ff": "0xEFE9",
    "1faf1_1f3fc": "0xEFEA",
    "1faf1_1f3fc_200d_1faf2_1f3fb": "0xEFEB",
    "1faf1_1f3fc_200d_1faf2_1f3fd": "0xEFEC",
    "1faf1_1f3fc_200d_1faf2_1f3fe": "0xEFED",
    "1faf1_1f3fc_200d_1faf2_1f3ff": "0xEFEE",
    "1faf1_1f3fd": "0xEFEF",
    "1faf1_1f3fd_200d_1faf2_1f3fb": "0xEFF0",
    "1faf1_1f3fd_200d_1faf2_1f3fc": "0xEFF1",
    "1faf1_1f3fd_200d_1faf2_1f3fe": "0xEFF2",
    "1faf1_1f3fd_200d_1faf2_1f3ff": "0xEFF3",
    "1faf1_1f3fe": "0xEFF4",
    "1faf1_1f3fe_200d_1faf2_1f3fb": "0xEFF5",
    "1faf1_1f3fe_200d_1faf2_1f3fc": "0xEFF6",
    "1faf1_1f3fe_200d_1faf2_1f3fd": "0xEFF7",
    "1faf1_1f3fe_200d_1faf2_1f3ff": "0xEFF8",
    "1faf1_1f3ff": "0xEFF9",
    "1faf1_1f3ff_200d_1faf2_1f3fb": "0xEFFA",
    "1faf1_1f3ff_200d_1faf2_1f3fc": "0xEFFB",
    "1faf1_1f3ff_200d_1faf2_1f3fd": "0xEFFC",
    "1faf1_1f3ff_200d_1faf2_1f3fe": "0xEFFD",
    "1faf2": "0xEFFE",
    "1faf2_1f3fb": "0xEFFF",
    "1faf2_1f3fc": "0xF000",
    "1faf2_1f3fd": "0xF001",
    "1faf2_1f3fe": "0xF002",
    "1faf2_1f3ff": "0xF003",
    "1faf3": "0xF004",
    "1faf3_1f3fb": "0xF005",
    "1faf3_1f3fc": "0xF006",
    "1faf3_1f3fd": "0xF007",
    "1faf3_1f3fe": "0xF008",
    "1faf3_1f3ff": "0xF009",
    "1faf4": "0xF00A",
    "1faf4_1f3fb": "0xF00B",
    "1faf4_1f3fc": "0xF00C",
    "1faf4_1f3fd": "0xF00D",
    "1faf4_1f3fe": "0xF00E",
    "1faf4_1f3ff": "0xF00F",
    "1faf5": "0xF010",
    "1faf5_1f3fb": "0xF011",
    "1faf5_1f3fc": "0xF012",
    "1faf5_1f3fd": "0xF013",
    "1faf5_1f3fe": "0xF014",
    "1faf5_1f3ff": "0xF015",
    "1faf6": "0xF016",
    "1faf6_1f3fb": "0xF017",
    "1faf6_1f3fc": "0xF018",
    "1faf6_1f3fd": "0xF019",
    "1faf6_1f3fe": "0xF01A",
    "1faf6_1f3ff": "0xF01B",
    "1faf7": "0xF01C",
    "1faf7_1f3fb": "0xF01D",
    "1faf7_1f3fc": "0xF01E",
    "1faf7_1f3fd": "0xF01F",
    "1faf7_1f3fe": "0xF020",
    "1faf7_1f3ff": "0xF021",
    "1faf8": "0xF022",
    "1faf8_1f3fb": "0xF023",
    "1faf8_1f3fc": "0xF024",
    "1faf8_1f3fd": "0xF025",
    "1faf8_1f3fe": "0xF026",
    "1faf8_1f3ff": "0xF027",
    "203c": "0xF028",
    "2049": "0xF029",
    "20e3": "0xF02A",
    "2122": "0xF02B",
    "2139": "0xF02C",
    "2194": "0xF02D",
    "2195": "0xF02E",
    "2196": "0xF02F",
    "2197": "0xF030",
    "2198": "0xF031",
    "2199": "0xF032",
    "21a9": "0xF033",
    "21aa": "0xF034",
    "231a": "0xF035",
    "231b": "0xF036",
    "2328": "0xF037",
    "23cf": "0xF038",
    "23e9": "0xF039",
    "23ea": "0xF03A",
    "23eb": "0xF03B",
    "23ec": "0xF03C",
    "23ed": "0xF03D",
    "23ee": "0xF03E",
    "23ef": "0xF03F",
    "23f0": "0xF040",
    "23f1": "0xF041",
    "23f2": "0xF042",
    "23f3": "0xF043",
    "23f8": "0xF044",
    "23f9": "0xF045",
    "23fa": "0xF046",
    "24c2": "0xF047",
    "25aa": "0xF048",
    "25ab": "0xF049",
    "25b6": "0xF04A",
    "25c0": "0xF04B",
    "25fb": "0xF04C",
    "25fc": "0xF04D",
    "25fd": "0xF04E",
    "25fe": "0xF04F",
    "2600": "0xF050",
    "2601": "0xF051",
    "2602": "0xF052",
    "2603": "0xF053",
    "2604": "0xF054",
    "260e": "0xF055",
    "2611": "0xF056",
    "2614": "0xF057",
    "2615": "0xF058",
    "2618": "0xF059",
    "261d": "0xF05A",
    "261d_1f3fb": "0xF05B",
    "261d_1f3fc": "0xF05C",
    "261d_1f3fd": "0xF05D",
    "261d_1f3fe": "0xF05E",
    "261d_1f3ff": "0xF05F",
    "2620": "0xF060",
    "2622": "0xF061",
    "2623": "0xF062",
    "2626": "0xF063",
    "262a": "0xF064",
    "262e": "0xF065",
    "262f": "0xF066",
    "2638": "0xF067",
    "2639": "0xF068",
    "263a": "0xF069",
    "2640": "0xF06A",
    "2642": "0xF06B",
    "2648": "0xF06C",
    "2649": "0xF06D",
    "264a": "0xF06E",
    "264b": "0xF06F",
    "264c": "0xF070",
    "264d": "0xF071",
    "264e": "0xF072",
    "264f": "0xF073",
    "2650": "0xF074",
    "2651": "0xF075",
    "2652": "0xF076",
    "2653": "0xF077",
    "265f": "0xF078",
    "2660": "0xF079",
    "2663": "0xF07A",
    "2665": "0xF07B",
    "2666": "0xF07C",
    "2668": "0xF07D",
    "267b": "0xF07E",
    "267e": "0xF07F",
    "267f": "0xF080",
    "2692": "0xF081",
    "2693": "0xF082",
    "2694": "0xF083",
    "2695": "0xF084",
    "2696": "0xF085",
    "2697": "0xF086",
    "2699": "0xF087",
    "269b": "0xF088",
    "269c": "0xF089",
    "26a0": "0xF08A",
    "26a1": "0xF08B",
    "26a7": "0xF08C",
    "26aa": "0xF08D",
    "26ab": "0xF08E",
    "26b0": "0xF08F",
    "26b1": "0xF090",
    "26bd": "0xF091",
    "26be": "0xF092",
    "26c4": "0xF093",
    "26c5": "0xF094",
    "26c8": "0xF095",
    "26ce": "0xF096",
    "26cf": "0xF097",
    "26d1": "0xF098",
    "26d3": "0xF099",
    "26d3_200d_1f4a5": "0xF09A",
    "26d4": "0xF09B",
    "26e9": "0xF09C",
    "26ea": "0xF09D",
    "26f0": "0xF09E",
    "26f1": "0xF09F",
    "26f2": "0xF0A0",
    "26f3": "0xF0A1",
    "26f4": "0xF0A2",
    "26f5": "0xF0A3",
    "26f7": "0xF0A4",
    "26f8": "0xF0A5",
    "26f9": "0xF0A6",
    "26f9_1f3fb": "0xF0A7",
    "26f9_1f3fb_200d_2640": "0xF0A8",
    "26f9_1f3fb_200d_2642": "0xF0A9",
    "26f9_1f3fc": "0xF0AA",
    "26f9_1f3fc_200d_2640": "0xF0AB",
    "26f9_1f3fc_200d_2642": "0xF0AC",
    "26f9_1f3fd": "0xF0AD",
    "26f9_1f3fd_200d_2640": "0xF0AE",
    "26f9_1f3fd_200d_2642": "0xF0AF",
    "26f9_1f3fe": "0xF0B0",
    "26f9_1f3fe_200d_2640": "0xF0B1",
    "26f9_1f3fe_200d_2642": "0xF0B2",
    "26f9_1f3ff": "0xF0B3",
    "26f9_1f3ff_200d_2640": "0xF0B4",
    "26f9_1f3ff_200d_2642": "0xF0B5",
    "26f9_200d_2640": "0xF0B6",
    "26f9_200d_2642": "0xF0B7",
    "26fa": "0xF0B8",
    "26fd": "0xF0B9",
    "2702": "0xF0BA",
    "2705": "0xF0BB",
    "2708": "0xF0BC",
    "2709": "0xF0BD",
    "270a": "0xF0BE",
    "270a_1f3fb": "0xF0BF",
    "270a_1f3fc": "0xF0C0",
    "270a_1f3fd": "0xF0C1",
    "270a_1f3fe": "0xF0C2",
    "270a_1f3ff": "0xF0C3",
    "270b": "0xF0C4",
    "270b_1f3fb": "0xF0C5",
    "270b_1f3fc": "0xF0C6",
    "270b_1f3fd": "0xF0C7",
    "270b_1f3fe": "0xF0C8",
    "270b_1f3ff": "0xF0C9",
    "270c": "0xF0CA",
    "270c_1f3fb": "0xF0CB",
    "270c_1f3fc": "0xF0CC",
    "270c_1f3fd": "0xF0CD",
    "270c_1f3fe": "0xF0CE",
    "270c_1f3ff": "0xF0CF",
    "270d": "0xF0D0",
    "270d_1f3fb": "0xF0D1",
    "270d_1f3fc": "0xF0D2",
    "270d_1f3fd": "0xF0D3",
    "270d_1f3fe": "0xF0D4",
    "270d_1f3ff": "0xF0D5",
    "270f": "0xF0D6",
    "2712": "0xF0D7",
    "2714": "0xF0D8",
    "2716": "0xF0D9",
    "271d": "0xF0DA",
    "2721": "0xF0DB",
    "2728": "0xF0DC",
    "2733": "0xF0DD",
    "2734": "0xF0DE",
    "2744": "0xF0DF",
    "2747": "0xF0E0",
    "274c": "0xF0E1",
    "274e": "0xF0E2",
    "2753": "0xF0E3",
    "2754": "0xF0E4",
    "2755": "0xF0E5",
    "2757": "0xF0E6",
    "2763": "0xF0E7",
    "2764": "0xF0E8",
    "2764_200d_1f525": "0xF0E9",
    "2764_200d_1fa79": "0xF0EA",
    "2795": "0xF0EB",
    "2796": "0xF0EC",
    "2797": "0xF0ED",
    "27a1": "0xF0EE",
    "27b0": "0xF0EF",
    "27bf": "0xF0F0",
    "2934": "0xF0F1",
    "2935": "0xF0F2",
    "2b05": "0xF0F3",
    "2b06": "0xF0F4",
    "2b07": "0xF0F5",
    "2b1b": "0xF0F6",
    "2b1c": "0xF0F7",
    "2b50": "0xF0F8",
    "2b55": "0xF0F9",
    "3030": "0xF0FA",
    "303d": "0xF0FB",
    "3297": "0xF0FC",
    "3299": "0xF0FD",
    "fe82b": "0xF0FE"
}